{-# LANGUAGE CPP, ForeignFunctionInterface, TupleSections #-}
-- | Binding for GDK key constants defined in @gdk/gdkkeysyms.h@
module Hbro.Gdk.KeyVal where

-- {{{ Imports
import Hbro.Prelude

import Data.Char

import qualified Graphics.UI.Gtk.Gdk.Keys as Gtk

import Text.Parsec hiding((<|>))
import Text.Parsec.Text

#include <gdk/gdkkeysyms.h>
-- }}}

newtype KeyVal = KeyVal { unKeyValue :: Word32 }
    deriving (Eq, Ord)

-- | Single characters are returned as is. For other keys, the corresponding keyName wrapped into @\<\>@ is returned.
instance Describable KeyVal where
    describe (KeyVal key) = name <| (length name < 2) |> ("<" ++ name ++ ">")
      where name = Gtk.keyName key

keyVal, shortKeyVal, longKeyVal :: Parser KeyVal
keyVal = spaces *> (shortKeyVal <|> longKeyVal)
shortKeyVal = KeyVal . fromIntegral . ord <$> noneOf "<>"
longKeyVal = KeyVal . Gtk.keyFromName . pack <$> between (char '<') (char '>') (many1 anyChar)


#{enum KeyVal, KeyVal,
    _VoidSymbol                  = GDK_KEY_VoidSymbol,
    _BackSpace                   = GDK_KEY_BackSpace,
    _Tab                         = GDK_KEY_Tab,
    _Linefeed                    = GDK_KEY_Linefeed,
    _Clear                       = GDK_KEY_Clear,
    _Return                      = GDK_KEY_Return,
    _Pause                       = GDK_KEY_Pause,
    _Scroll_Lock                 = GDK_KEY_Scroll_Lock,
    _Sys_Req                     = GDK_KEY_Sys_Req,
    _Escape                      = GDK_KEY_Escape,
    _Delete                      = GDK_KEY_Delete,
    _Multi_key                   = GDK_KEY_Multi_key,
    _Codeinput                   = GDK_KEY_Codeinput,
    _SingleCandidate             = GDK_KEY_SingleCandidate,
    _MultipleCandidate           = GDK_KEY_MultipleCandidate,
    _PreviousCandidate           = GDK_KEY_PreviousCandidate,
    _Kanji                       = GDK_KEY_Kanji,
    _Muhenkan                    = GDK_KEY_Muhenkan,
    _Henkan_Mode                 = GDK_KEY_Henkan_Mode,
    _Henkan                      = GDK_KEY_Henkan,
    _Romaji                      = GDK_KEY_Romaji,
    _Hiragana                    = GDK_KEY_Hiragana,
    _Katakana                    = GDK_KEY_Katakana,
    _Hiragana_Katakana           = GDK_KEY_Hiragana_Katakana,
    _Zenkaku                     = GDK_KEY_Zenkaku,
    _Hankaku                     = GDK_KEY_Hankaku,
    _Zenkaku_Hankaku             = GDK_KEY_Zenkaku_Hankaku,
    _Touroku                     = GDK_KEY_Touroku,
    _Massyo                      = GDK_KEY_Massyo,
    _Kana_Lock                   = GDK_KEY_Kana_Lock,
    _Kana_Shift                  = GDK_KEY_Kana_Shift,
    _Eisu_Shift                  = GDK_KEY_Eisu_Shift,
    _Eisu_toggle                 = GDK_KEY_Eisu_toggle,
    _Kanji_Bangou                = GDK_KEY_Kanji_Bangou,
    _Zen_Koho                    = GDK_KEY_Zen_Koho,
    _Mae_Koho                    = GDK_KEY_Mae_Koho,
    _Home                        = GDK_KEY_Home,
    _Left                        = GDK_KEY_Left,
    _Up                          = GDK_KEY_Up,
    _Right                       = GDK_KEY_Right,
    _Down                        = GDK_KEY_Down,
    _Prior                       = GDK_KEY_Prior,
    _Page_Up                     = GDK_KEY_Page_Up,
    _Next                        = GDK_KEY_Next,
    _Page_Down                   = GDK_KEY_Page_Down,
    _End                         = GDK_KEY_End,
    _Begin                       = GDK_KEY_Begin,
    _Select                      = GDK_KEY_Select,
    _Print                       = GDK_KEY_Print,
    _Execute                     = GDK_KEY_Execute,
    _Insert                      = GDK_KEY_Insert,
    _Undo                        = GDK_KEY_Undo,
    _Redo                        = GDK_KEY_Redo,
    _Menu                        = GDK_KEY_Menu,
    _Find                        = GDK_KEY_Find,
    _Cancel                      = GDK_KEY_Cancel,
    _Help                        = GDK_KEY_Help,
    _Break                       = GDK_KEY_Break,
    _Mode_switch                 = GDK_KEY_Mode_switch,
    _script_switch               = GDK_KEY_script_switch,
    _Num_Lock                    = GDK_KEY_Num_Lock,
    _KP_Space                    = GDK_KEY_KP_Space,
    _KP_Tab                      = GDK_KEY_KP_Tab,
    _KP_Enter                    = GDK_KEY_KP_Enter,
    _KP_F1                       = GDK_KEY_KP_F1,
    _KP_F2                       = GDK_KEY_KP_F2,
    _KP_F3                       = GDK_KEY_KP_F3,
    _KP_F4                       = GDK_KEY_KP_F4,
    _KP_Home                     = GDK_KEY_KP_Home,
    _KP_Left                     = GDK_KEY_KP_Left,
    _KP_Up                       = GDK_KEY_KP_Up,
    _KP_Right                    = GDK_KEY_KP_Right,
    _KP_Down                     = GDK_KEY_KP_Down,
    _KP_Prior                    = GDK_KEY_KP_Prior,
    _KP_Page_Up                  = GDK_KEY_KP_Page_Up,
    _KP_Next                     = GDK_KEY_KP_Next,
    _KP_Page_Down                = GDK_KEY_KP_Page_Down,
    _KP_End                      = GDK_KEY_KP_End,
    _KP_Begin                    = GDK_KEY_KP_Begin,
    _KP_Insert                   = GDK_KEY_KP_Insert,
    _KP_Delete                   = GDK_KEY_KP_Delete,
    _KP_Equal                    = GDK_KEY_KP_Equal,
    _KP_Multiply                 = GDK_KEY_KP_Multiply,
    _KP_Add                      = GDK_KEY_KP_Add,
    _KP_Separator                = GDK_KEY_KP_Separator,
    _KP_Subtract                 = GDK_KEY_KP_Subtract,
    _KP_Decimal                  = GDK_KEY_KP_Decimal,
    _KP_Divide                   = GDK_KEY_KP_Divide,
    _KP_0                        = GDK_KEY_KP_0,
    _KP_1                        = GDK_KEY_KP_1,
    _KP_2                        = GDK_KEY_KP_2,
    _KP_3                        = GDK_KEY_KP_3,
    _KP_4                        = GDK_KEY_KP_4,
    _KP_5                        = GDK_KEY_KP_5,
    _KP_6                        = GDK_KEY_KP_6,
    _KP_7                        = GDK_KEY_KP_7,
    _KP_8                        = GDK_KEY_KP_8,
    _KP_9                        = GDK_KEY_KP_9,
    _F1                          = GDK_KEY_F1,
    _F2                          = GDK_KEY_F2,
    _F3                          = GDK_KEY_F3,
    _F4                          = GDK_KEY_F4,
    _F5                          = GDK_KEY_F5,
    _F6                          = GDK_KEY_F6,
    _F7                          = GDK_KEY_F7,
    _F8                          = GDK_KEY_F8,
    _F9                          = GDK_KEY_F9,
    _F10                         = GDK_KEY_F10,
    _F11                         = GDK_KEY_F11,
    _L1                          = GDK_KEY_L1,
    _F12                         = GDK_KEY_F12,
    _L2                          = GDK_KEY_L2,
    _F13                         = GDK_KEY_F13,
    _L3                          = GDK_KEY_L3,
    _F14                         = GDK_KEY_F14,
    _L4                          = GDK_KEY_L4,
    _F15                         = GDK_KEY_F15,
    _L5                          = GDK_KEY_L5,
    _F16                         = GDK_KEY_F16,
    _L6                          = GDK_KEY_L6,
    _F17                         = GDK_KEY_F17,
    _L7                          = GDK_KEY_L7,
    _F18                         = GDK_KEY_F18,
    _L8                          = GDK_KEY_L8,
    _F19                         = GDK_KEY_F19,
    _L9                          = GDK_KEY_L9,
    _F20                         = GDK_KEY_F20,
    _L10                         = GDK_KEY_L10,
    _F21                         = GDK_KEY_F21,
    _R1                          = GDK_KEY_R1,
    _F22                         = GDK_KEY_F22,
    _R2                          = GDK_KEY_R2,
    _F23                         = GDK_KEY_F23,
    _R3                          = GDK_KEY_R3,
    _F24                         = GDK_KEY_F24,
    _R4                          = GDK_KEY_R4,
    _F25                         = GDK_KEY_F25,
    _R5                          = GDK_KEY_R5,
    _F26                         = GDK_KEY_F26,
    _R6                          = GDK_KEY_R6,
    _F27                         = GDK_KEY_F27,
    _R7                          = GDK_KEY_R7,
    _F28                         = GDK_KEY_F28,
    _R8                          = GDK_KEY_R8,
    _F29                         = GDK_KEY_F29,
    _R9                          = GDK_KEY_R9,
    _F30                         = GDK_KEY_F30,
    _R10                         = GDK_KEY_R10,
    _F31                         = GDK_KEY_F31,
    _R11                         = GDK_KEY_R11,
    _F32                         = GDK_KEY_F32,
    _R12                         = GDK_KEY_R12,
    _F33                         = GDK_KEY_F33,
    _R13                         = GDK_KEY_R13,
    _F34                         = GDK_KEY_F34,
    _R14                         = GDK_KEY_R14,
    _F35                         = GDK_KEY_F35,
    _R15                         = GDK_KEY_R15,
    _Shift_L                     = GDK_KEY_Shift_L,
    _Shift_R                     = GDK_KEY_Shift_R,
    _Control_L                   = GDK_KEY_Control_L,
    _Control_R                   = GDK_KEY_Control_R,
    _Caps_Lock                   = GDK_KEY_Caps_Lock,
    _Shift_Lock                  = GDK_KEY_Shift_Lock,
    _Meta_L                      = GDK_KEY_Meta_L,
    _Meta_R                      = GDK_KEY_Meta_R,
    _Alt_L                       = GDK_KEY_Alt_L,
    _Alt_R                       = GDK_KEY_Alt_R,
    _Super_L                     = GDK_KEY_Super_L,
    _Super_R                     = GDK_KEY_Super_R,
    _Hyper_L                     = GDK_KEY_Hyper_L,
    _Hyper_R                     = GDK_KEY_Hyper_R,
    _ISO_Lock                    = GDK_KEY_ISO_Lock,
    _ISO_Level2_Latch            = GDK_KEY_ISO_Level2_Latch,
    _ISO_Level3_Shift            = GDK_KEY_ISO_Level3_Shift,
    _ISO_Level3_Latch            = GDK_KEY_ISO_Level3_Latch,
    _ISO_Level3_Lock             = GDK_KEY_ISO_Level3_Lock,
    _ISO_Level5_Shift            = GDK_KEY_ISO_Level5_Shift,
    _ISO_Level5_Latch            = GDK_KEY_ISO_Level5_Latch,
    _ISO_Level5_Lock             = GDK_KEY_ISO_Level5_Lock,
    _ISO_Group_Shift             = GDK_KEY_ISO_Group_Shift,
    _ISO_Group_Latch             = GDK_KEY_ISO_Group_Latch,
    _ISO_Group_Lock              = GDK_KEY_ISO_Group_Lock,
    _ISO_Next_Group              = GDK_KEY_ISO_Next_Group,
    _ISO_Next_Group_Lock         = GDK_KEY_ISO_Next_Group_Lock,
    _ISO_Prev_Group              = GDK_KEY_ISO_Prev_Group,
    _ISO_Prev_Group_Lock         = GDK_KEY_ISO_Prev_Group_Lock,
    _ISO_First_Group             = GDK_KEY_ISO_First_Group,
    _ISO_First_Group_Lock        = GDK_KEY_ISO_First_Group_Lock,
    _ISO_Last_Group              = GDK_KEY_ISO_Last_Group,
    _ISO_Last_Group_Lock         = GDK_KEY_ISO_Last_Group_Lock,
    _ISO_Left_Tab                = GDK_KEY_ISO_Left_Tab,
    _ISO_Move_Line_Up            = GDK_KEY_ISO_Move_Line_Up,
    _ISO_Move_Line_Down          = GDK_KEY_ISO_Move_Line_Down,
    _ISO_Partial_Line_Up         = GDK_KEY_ISO_Partial_Line_Up,
    _ISO_Partial_Line_Down       = GDK_KEY_ISO_Partial_Line_Down,
    _ISO_Partial_Space_Left      = GDK_KEY_ISO_Partial_Space_Left,
    _ISO_Partial_Space_Right     = GDK_KEY_ISO_Partial_Space_Right,
    _ISO_Set_Margin_Left         = GDK_KEY_ISO_Set_Margin_Left,
    _ISO_Set_Margin_Right        = GDK_KEY_ISO_Set_Margin_Right,
    _ISO_Release_Margin_Left     = GDK_KEY_ISO_Release_Margin_Left,
    _ISO_Release_Margin_Right    = GDK_KEY_ISO_Release_Margin_Right,
    _ISO_Release_Both_Margins    = GDK_KEY_ISO_Release_Both_Margins,
    _ISO_Fast_Cursor_Left        = GDK_KEY_ISO_Fast_Cursor_Left,
    _ISO_Fast_Cursor_Right       = GDK_KEY_ISO_Fast_Cursor_Right,
    _ISO_Fast_Cursor_Up          = GDK_KEY_ISO_Fast_Cursor_Up,
    _ISO_Fast_Cursor_Down        = GDK_KEY_ISO_Fast_Cursor_Down,
    _ISO_Continuous_Underline    = GDK_KEY_ISO_Continuous_Underline,
    _ISO_Discontinuous_Underline = GDK_KEY_ISO_Discontinuous_Underline,
    _ISO_Emphasize               = GDK_KEY_ISO_Emphasize,
    _ISO_Center_Object           = GDK_KEY_ISO_Center_Object,
    _ISO_Enter                   = GDK_KEY_ISO_Enter,
    _dead_grave                  = GDK_KEY_dead_grave,
    _dead_acute                  = GDK_KEY_dead_acute,
    _dead_circumflex             = GDK_KEY_dead_circumflex,
    _dead_tilde                  = GDK_KEY_dead_tilde,
    _dead_perispomeni            = GDK_KEY_dead_perispomeni,
    _dead_macron                 = GDK_KEY_dead_macron,
    _dead_breve                  = GDK_KEY_dead_breve,
    _dead_abovedot               = GDK_KEY_dead_abovedot,
    _dead_diaeresis              = GDK_KEY_dead_diaeresis,
    _dead_abovering              = GDK_KEY_dead_abovering,
    _dead_doubleacute            = GDK_KEY_dead_doubleacute,
    _dead_caron                  = GDK_KEY_dead_caron,
    _dead_cedilla                = GDK_KEY_dead_cedilla,
    _dead_ogonek                 = GDK_KEY_dead_ogonek,
    _dead_iota                   = GDK_KEY_dead_iota,
    _dead_voiced_sound           = GDK_KEY_dead_voiced_sound,
    _dead_semivoiced_sound       = GDK_KEY_dead_semivoiced_sound,
    _dead_belowdot               = GDK_KEY_dead_belowdot,
    _dead_hook                   = GDK_KEY_dead_hook,
    _dead_horn                   = GDK_KEY_dead_horn,
    _dead_stroke                 = GDK_KEY_dead_stroke,
    _dead_abovecomma             = GDK_KEY_dead_abovecomma,
    _dead_psili                  = GDK_KEY_dead_psili,
    _dead_abovereversedcomma     = GDK_KEY_dead_abovereversedcomma,
    _dead_dasia                  = GDK_KEY_dead_dasia,
    _dead_doublegrave            = GDK_KEY_dead_doublegrave,
    _dead_belowring              = GDK_KEY_dead_belowring,
    _dead_belowmacron            = GDK_KEY_dead_belowmacron,
    _dead_belowcircumflex        = GDK_KEY_dead_belowcircumflex,
    _dead_belowtilde             = GDK_KEY_dead_belowtilde,
    _dead_belowbreve             = GDK_KEY_dead_belowbreve,
    _dead_belowdiaeresis         = GDK_KEY_dead_belowdiaeresis,
    _dead_invertedbreve          = GDK_KEY_dead_invertedbreve,
    _dead_belowcomma             = GDK_KEY_dead_belowcomma,
    _dead_currency               = GDK_KEY_dead_currency,
    _dead_a                      = GDK_KEY_dead_a,
    _dead_A                      = GDK_KEY_dead_A,
    _dead_e                      = GDK_KEY_dead_e,
    _dead_E                      = GDK_KEY_dead_E,
    _dead_i                      = GDK_KEY_dead_i,
    _dead_I                      = GDK_KEY_dead_I,
    _dead_o                      = GDK_KEY_dead_o,
    _dead_O                      = GDK_KEY_dead_O,
    _dead_u                      = GDK_KEY_dead_u,
    _dead_U                      = GDK_KEY_dead_U,
    _dead_small_schwa            = GDK_KEY_dead_small_schwa,
    _dead_capital_schwa          = GDK_KEY_dead_capital_schwa,
    _First_Virtual_Screen        = GDK_KEY_First_Virtual_Screen,
    _Prev_Virtual_Screen         = GDK_KEY_Prev_Virtual_Screen,
    _Next_Virtual_Screen         = GDK_KEY_Next_Virtual_Screen,
    _Last_Virtual_Screen         = GDK_KEY_Last_Virtual_Screen,
    _Terminate_Server            = GDK_KEY_Terminate_Server,
    _AccessX_Enable              = GDK_KEY_AccessX_Enable,
    _AccessX_Feedback_Enable     = GDK_KEY_AccessX_Feedback_Enable,
    _RepeatKeys_Enable           = GDK_KEY_RepeatKeys_Enable,
    _SlowKeys_Enable             = GDK_KEY_SlowKeys_Enable,
    _BounceKeys_Enable           = GDK_KEY_BounceKeys_Enable,
    _StickyKeys_Enable           = GDK_KEY_StickyKeys_Enable,
    _MouseKeys_Enable            = GDK_KEY_MouseKeys_Enable,
    _MouseKeys_Accel_Enable      = GDK_KEY_MouseKeys_Accel_Enable,
    _Overlay1_Enable             = GDK_KEY_Overlay1_Enable,
    _Overlay2_Enable             = GDK_KEY_Overlay2_Enable,
    _AudibleBell_Enable          = GDK_KEY_AudibleBell_Enable,
    _Pointer_Left                = GDK_KEY_Pointer_Left,
    _Pointer_Right               = GDK_KEY_Pointer_Right,
    _Pointer_Up                  = GDK_KEY_Pointer_Up,
    _Pointer_Down                = GDK_KEY_Pointer_Down,
    _Pointer_UpLeft              = GDK_KEY_Pointer_UpLeft,
    _Pointer_UpRight             = GDK_KEY_Pointer_UpRight,
    _Pointer_DownLeft            = GDK_KEY_Pointer_DownLeft,
    _Pointer_DownRight           = GDK_KEY_Pointer_DownRight,
    _Pointer_Button_Dflt         = GDK_KEY_Pointer_Button_Dflt,
    _Pointer_Button1             = GDK_KEY_Pointer_Button1,
    _Pointer_Button2             = GDK_KEY_Pointer_Button2,
    _Pointer_Button3             = GDK_KEY_Pointer_Button3,
    _Pointer_Button4             = GDK_KEY_Pointer_Button4,
    _Pointer_Button5             = GDK_KEY_Pointer_Button5,
    _Pointer_DblClick_Dflt       = GDK_KEY_Pointer_DblClick_Dflt,
    _Pointer_DblClick1           = GDK_KEY_Pointer_DblClick1,
    _Pointer_DblClick2           = GDK_KEY_Pointer_DblClick2,
    _Pointer_DblClick3           = GDK_KEY_Pointer_DblClick3,
    _Pointer_DblClick4           = GDK_KEY_Pointer_DblClick4,
    _Pointer_DblClick5           = GDK_KEY_Pointer_DblClick5,
    _Pointer_Drag_Dflt           = GDK_KEY_Pointer_Drag_Dflt,
    _Pointer_Drag1               = GDK_KEY_Pointer_Drag1,
    _Pointer_Drag2               = GDK_KEY_Pointer_Drag2,
    _Pointer_Drag3               = GDK_KEY_Pointer_Drag3,
    _Pointer_Drag4               = GDK_KEY_Pointer_Drag4,
    _Pointer_Drag5               = GDK_KEY_Pointer_Drag5,
    _Pointer_EnableKeys          = GDK_KEY_Pointer_EnableKeys,
    _Pointer_Accelerate          = GDK_KEY_Pointer_Accelerate,
    _Pointer_DfltBtnNext         = GDK_KEY_Pointer_DfltBtnNext,
    _Pointer_DfltBtnPrev         = GDK_KEY_Pointer_DfltBtnPrev,
    _3270_Duplicate              = GDK_KEY_3270_Duplicate,
    _3270_FieldMark              = GDK_KEY_3270_FieldMark,
    _3270_Right2                 = GDK_KEY_3270_Right2,
    _3270_Left2                  = GDK_KEY_3270_Left2,
    _3270_BackTab                = GDK_KEY_3270_BackTab,
    _3270_EraseEOF               = GDK_KEY_3270_EraseEOF,
    _3270_EraseInput             = GDK_KEY_3270_EraseInput,
    _3270_Reset                  = GDK_KEY_3270_Reset,
    _3270_Quit                   = GDK_KEY_3270_Quit,
    _3270_PA1                    = GDK_KEY_3270_PA1,
    _3270_PA2                    = GDK_KEY_3270_PA2,
    _3270_PA3                    = GDK_KEY_3270_PA3,
    _3270_Test                   = GDK_KEY_3270_Test,
    _3270_Attn                   = GDK_KEY_3270_Attn,
    _3270_CursorBlink            = GDK_KEY_3270_CursorBlink,
    _3270_AltCursor              = GDK_KEY_3270_AltCursor,
    _3270_KeyClick               = GDK_KEY_3270_KeyClick,
    _3270_Jump                   = GDK_KEY_3270_Jump,
    _3270_Ident                  = GDK_KEY_3270_Ident,
    _3270_Rule                   = GDK_KEY_3270_Rule,
    _3270_Copy                   = GDK_KEY_3270_Copy,
    _3270_Play                   = GDK_KEY_3270_Play,
    _3270_Setup                  = GDK_KEY_3270_Setup,
    _3270_Record                 = GDK_KEY_3270_Record,
    _3270_ChangeScreen           = GDK_KEY_3270_ChangeScreen,
    _3270_DeleteWord             = GDK_KEY_3270_DeleteWord,
    _3270_ExSelect               = GDK_KEY_3270_ExSelect,
    _3270_CursorSelect           = GDK_KEY_3270_CursorSelect,
    _3270_PrintScreen            = GDK_KEY_3270_PrintScreen,
    _3270_Enter                  = GDK_KEY_3270_Enter,
    _space                       = GDK_KEY_space,
    _exclam                      = GDK_KEY_exclam,
    _quotedbl                    = GDK_KEY_quotedbl,
    _numbersign                  = GDK_KEY_numbersign,
    _dollar                      = GDK_KEY_dollar,
    _percent                     = GDK_KEY_percent,
    _ampersand                   = GDK_KEY_ampersand,
    _apostrophe                  = GDK_KEY_apostrophe,
    _quoteright                  = GDK_KEY_quoteright,
    _parenleft                   = GDK_KEY_parenleft,
    _parenright                  = GDK_KEY_parenright,
    _asterisk                    = GDK_KEY_asterisk,
    _plus                        = GDK_KEY_plus,
    _comma                       = GDK_KEY_comma,
    _minus                       = GDK_KEY_minus,
    _period                      = GDK_KEY_period,
    _slash                       = GDK_KEY_slash,
    _0                           = GDK_KEY_0,
    _1                           = GDK_KEY_1,
    _2                           = GDK_KEY_2,
    _3                           = GDK_KEY_3,
    _4                           = GDK_KEY_4,
    _5                           = GDK_KEY_5,
    _6                           = GDK_KEY_6,
    _7                           = GDK_KEY_7,
    _8                           = GDK_KEY_8,
    _9                           = GDK_KEY_9,
    _colon                       = GDK_KEY_colon,
    _semicolon                   = GDK_KEY_semicolon,
    _less                        = GDK_KEY_less,
    _equal                       = GDK_KEY_equal,
    _greater                     = GDK_KEY_greater,
    _question                    = GDK_KEY_question,
    _at                          = GDK_KEY_at,
    _A                           = GDK_KEY_A,
    _B                           = GDK_KEY_B,
    _C                           = GDK_KEY_C,
    _D                           = GDK_KEY_D,
    _E                           = GDK_KEY_E,
    _F                           = GDK_KEY_F,
    _G                           = GDK_KEY_G,
    _H                           = GDK_KEY_H,
    _I                           = GDK_KEY_I,
    _J                           = GDK_KEY_J,
    _K                           = GDK_KEY_K,
    _L                           = GDK_KEY_L,
    _M                           = GDK_KEY_M,
    _N                           = GDK_KEY_N,
    _O                           = GDK_KEY_O,
    _P                           = GDK_KEY_P,
    _Q                           = GDK_KEY_Q,
    _R                           = GDK_KEY_R,
    _S                           = GDK_KEY_S,
    _T                           = GDK_KEY_T,
    _U                           = GDK_KEY_U,
    _V                           = GDK_KEY_V,
    _W                           = GDK_KEY_W,
    _X                           = GDK_KEY_X,
    _Y                           = GDK_KEY_Y,
    _Z                           = GDK_KEY_Z,
    _bracketleft                 = GDK_KEY_bracketleft,
    _backslash                   = GDK_KEY_backslash,
    _bracketright                = GDK_KEY_bracketright,
    _asciicircum                 = GDK_KEY_asciicircum,
    _underscore                  = GDK_KEY_underscore,
    _grave                       = GDK_KEY_grave,
    _quoteleft                   = GDK_KEY_quoteleft,
    _a                           = GDK_KEY_a,
    _b                           = GDK_KEY_b,
    _c                           = GDK_KEY_c,
    _d                           = GDK_KEY_d,
    _e                           = GDK_KEY_e,
    _f                           = GDK_KEY_f,
    _g                           = GDK_KEY_g,
    _h                           = GDK_KEY_h,
    _i                           = GDK_KEY_i,
    _j                           = GDK_KEY_j,
    _k                           = GDK_KEY_k,
    _l                           = GDK_KEY_l,
    _m                           = GDK_KEY_m,
    _n                           = GDK_KEY_n,
    _o                           = GDK_KEY_o,
    _p                           = GDK_KEY_p,
    _q                           = GDK_KEY_q,
    _r                           = GDK_KEY_r,
    _s                           = GDK_KEY_s,
    _t                           = GDK_KEY_t,
    _u                           = GDK_KEY_u,
    _v                           = GDK_KEY_v,
    _w                           = GDK_KEY_w,
    _x                           = GDK_KEY_x,
    _y                           = GDK_KEY_y,
    _z                           = GDK_KEY_z,
    _braceleft                   = GDK_KEY_braceleft,
    _bar                         = GDK_KEY_bar,
    _braceright                  = GDK_KEY_braceright,
    _asciitilde                  = GDK_KEY_asciitilde,
    _nobreakspace                = GDK_KEY_nobreakspace,
    _exclamdown                  = GDK_KEY_exclamdown,
    _cent                        = GDK_KEY_cent,
    _sterling                    = GDK_KEY_sterling,
    _currency                    = GDK_KEY_currency,
    _yen                         = GDK_KEY_yen,
    _brokenbar                   = GDK_KEY_brokenbar,
    _section                     = GDK_KEY_section,
    _diaeresis                   = GDK_KEY_diaeresis,
    _copyright                   = GDK_KEY_copyright,
    _ordfeminine                 = GDK_KEY_ordfeminine,
    _guillemotleft               = GDK_KEY_guillemotleft,
    _notsign                     = GDK_KEY_notsign,
    _hyphen                      = GDK_KEY_hyphen,
    _registered                  = GDK_KEY_registered,
    _macron                      = GDK_KEY_macron,
    _degree                      = GDK_KEY_degree,
    _plusminus                   = GDK_KEY_plusminus,
    _twosuperior                 = GDK_KEY_twosuperior,
    _threesuperior               = GDK_KEY_threesuperior,
    _acute                       = GDK_KEY_acute,
    _mu                          = GDK_KEY_mu,
    _paragraph                   = GDK_KEY_paragraph,
    _periodcentered              = GDK_KEY_periodcentered,
    _cedilla                     = GDK_KEY_cedilla,
    _onesuperior                 = GDK_KEY_onesuperior,
    _masculine                   = GDK_KEY_masculine,
    _guillemotright              = GDK_KEY_guillemotright,
    _onequarter                  = GDK_KEY_onequarter,
    _onehalf                     = GDK_KEY_onehalf,
    _threequarters               = GDK_KEY_threequarters,
    _questiondown                = GDK_KEY_questiondown,
    _Agrave                      = GDK_KEY_Agrave,
    _Aacute                      = GDK_KEY_Aacute,
    _Acircumflex                 = GDK_KEY_Acircumflex,
    _Atilde                      = GDK_KEY_Atilde,
    _Adiaeresis                  = GDK_KEY_Adiaeresis,
    _Aring                       = GDK_KEY_Aring,
    _AE                          = GDK_KEY_AE,
    _Ccedilla                    = GDK_KEY_Ccedilla,
    _Egrave                      = GDK_KEY_Egrave,
    _Eacute                      = GDK_KEY_Eacute,
    _Ecircumflex                 = GDK_KEY_Ecircumflex,
    _Ediaeresis                  = GDK_KEY_Ediaeresis,
    _Igrave                      = GDK_KEY_Igrave,
    _Iacute                      = GDK_KEY_Iacute,
    _Icircumflex                 = GDK_KEY_Icircumflex,
    _Idiaeresis                  = GDK_KEY_Idiaeresis,
    _ETH                         = GDK_KEY_ETH,
    _Eth                         = GDK_KEY_Eth,
    _Ntilde                      = GDK_KEY_Ntilde,
    _Ograve                      = GDK_KEY_Ograve,
    _Oacute                      = GDK_KEY_Oacute,
    _Ocircumflex                 = GDK_KEY_Ocircumflex,
    _Otilde                      = GDK_KEY_Otilde,
    _Odiaeresis                  = GDK_KEY_Odiaeresis,
    _multiply                    = GDK_KEY_multiply,
    _Oslash                      = GDK_KEY_Oslash,
    _Ooblique                    = GDK_KEY_Ooblique,
    _Ugrave                      = GDK_KEY_Ugrave,
    _Uacute                      = GDK_KEY_Uacute,
    _Ucircumflex                 = GDK_KEY_Ucircumflex,
    _Udiaeresis                  = GDK_KEY_Udiaeresis,
    _Yacute                      = GDK_KEY_Yacute,
    _THORN                       = GDK_KEY_THORN,
    _Thorn                       = GDK_KEY_Thorn,
    _ssharp                      = GDK_KEY_ssharp,
    _agrave                      = GDK_KEY_agrave,
    _aacute                      = GDK_KEY_aacute,
    _acircumflex                 = GDK_KEY_acircumflex,
    _atilde                      = GDK_KEY_atilde,
    _adiaeresis                  = GDK_KEY_adiaeresis,
    _aring                       = GDK_KEY_aring,
    _ae                          = GDK_KEY_ae,
    _ccedilla                    = GDK_KEY_ccedilla,
    _egrave                      = GDK_KEY_egrave,
    _eacute                      = GDK_KEY_eacute,
    _ecircumflex                 = GDK_KEY_ecircumflex,
    _ediaeresis                  = GDK_KEY_ediaeresis,
    _igrave                      = GDK_KEY_igrave,
    _iacute                      = GDK_KEY_iacute,
    _icircumflex                 = GDK_KEY_icircumflex,
    _idiaeresis                  = GDK_KEY_idiaeresis,
    _eth                         = GDK_KEY_eth,
    _ntilde                      = GDK_KEY_ntilde,
    _ograve                      = GDK_KEY_ograve,
    _oacute                      = GDK_KEY_oacute,
    _ocircumflex                 = GDK_KEY_ocircumflex,
    _otilde                      = GDK_KEY_otilde,
    _odiaeresis                  = GDK_KEY_odiaeresis,
    _division                    = GDK_KEY_division,
    _oslash                      = GDK_KEY_oslash,
    _ooblique                    = GDK_KEY_ooblique,
    _ugrave                      = GDK_KEY_ugrave,
    _uacute                      = GDK_KEY_uacute,
    _ucircumflex                 = GDK_KEY_ucircumflex,
    _udiaeresis                  = GDK_KEY_udiaeresis,
    _yacute                      = GDK_KEY_yacute,
    _thorn                       = GDK_KEY_thorn,
    _ydiaeresis                  = GDK_KEY_ydiaeresis,
    _Aogonek                     = GDK_KEY_Aogonek,
    _breve                       = GDK_KEY_breve,
    _Lstroke                     = GDK_KEY_Lstroke,
    _Lcaron                      = GDK_KEY_Lcaron,
    _Sacute                      = GDK_KEY_Sacute,
    _Scaron                      = GDK_KEY_Scaron,
    _Scedilla                    = GDK_KEY_Scedilla,
    _Tcaron                      = GDK_KEY_Tcaron,
    _Zacute                      = GDK_KEY_Zacute,
    _Zcaron                      = GDK_KEY_Zcaron,
    _Zabovedot                   = GDK_KEY_Zabovedot,
    _aogonek                     = GDK_KEY_aogonek,
    _ogonek                      = GDK_KEY_ogonek,
    _lstroke                     = GDK_KEY_lstroke,
    _lcaron                      = GDK_KEY_lcaron,
    _sacute                      = GDK_KEY_sacute,
    _caron                       = GDK_KEY_caron,
    _scaron                      = GDK_KEY_scaron,
    _scedilla                    = GDK_KEY_scedilla,
    _tcaron                      = GDK_KEY_tcaron,
    _zacute                      = GDK_KEY_zacute,
    _doubleacute                 = GDK_KEY_doubleacute,
    _zcaron                      = GDK_KEY_zcaron,
    _zabovedot                   = GDK_KEY_zabovedot,
    _Racute                      = GDK_KEY_Racute,
    _Abreve                      = GDK_KEY_Abreve,
    _Lacute                      = GDK_KEY_Lacute,
    _Cacute                      = GDK_KEY_Cacute,
    _Ccaron                      = GDK_KEY_Ccaron,
    _Eogonek                     = GDK_KEY_Eogonek,
    _Ecaron                      = GDK_KEY_Ecaron,
    _Dcaron                      = GDK_KEY_Dcaron,
    _Dstroke                     = GDK_KEY_Dstroke,
    _Nacute                      = GDK_KEY_Nacute,
    _Ncaron                      = GDK_KEY_Ncaron,
    _Odoubleacute                = GDK_KEY_Odoubleacute,
    _Rcaron                      = GDK_KEY_Rcaron,
    _Uring                       = GDK_KEY_Uring,
    _Udoubleacute                = GDK_KEY_Udoubleacute,
    _Tcedilla                    = GDK_KEY_Tcedilla,
    _racute                      = GDK_KEY_racute,
    _abreve                      = GDK_KEY_abreve,
    _lacute                      = GDK_KEY_lacute,
    _cacute                      = GDK_KEY_cacute,
    _ccaron                      = GDK_KEY_ccaron,
    _eogonek                     = GDK_KEY_eogonek,
    _ecaron                      = GDK_KEY_ecaron,
    _dcaron                      = GDK_KEY_dcaron,
    _dstroke                     = GDK_KEY_dstroke,
    _nacute                      = GDK_KEY_nacute,
    _ncaron                      = GDK_KEY_ncaron,
    _odoubleacute                = GDK_KEY_odoubleacute,
    _rcaron                      = GDK_KEY_rcaron,
    _uring                       = GDK_KEY_uring,
    _udoubleacute                = GDK_KEY_udoubleacute,
    _tcedilla                    = GDK_KEY_tcedilla,
    _abovedot                    = GDK_KEY_abovedot,
    _Hstroke                     = GDK_KEY_Hstroke,
    _Hcircumflex                 = GDK_KEY_Hcircumflex,
    _Iabovedot                   = GDK_KEY_Iabovedot,
    _Gbreve                      = GDK_KEY_Gbreve,
    _Jcircumflex                 = GDK_KEY_Jcircumflex,
    _hstroke                     = GDK_KEY_hstroke,
    _hcircumflex                 = GDK_KEY_hcircumflex,
    _idotless                    = GDK_KEY_idotless,
    _gbreve                      = GDK_KEY_gbreve,
    _jcircumflex                 = GDK_KEY_jcircumflex,
    _Cabovedot                   = GDK_KEY_Cabovedot,
    _Ccircumflex                 = GDK_KEY_Ccircumflex,
    _Gabovedot                   = GDK_KEY_Gabovedot,
    _Gcircumflex                 = GDK_KEY_Gcircumflex,
    _Ubreve                      = GDK_KEY_Ubreve,
    _Scircumflex                 = GDK_KEY_Scircumflex,
    _cabovedot                   = GDK_KEY_cabovedot,
    _ccircumflex                 = GDK_KEY_ccircumflex,
    _gabovedot                   = GDK_KEY_gabovedot,
    _gcircumflex                 = GDK_KEY_gcircumflex,
    _ubreve                      = GDK_KEY_ubreve,
    _scircumflex                 = GDK_KEY_scircumflex,
    _kra                         = GDK_KEY_kra,
    _kappa                       = GDK_KEY_kappa,
    _Rcedilla                    = GDK_KEY_Rcedilla,
    _Itilde                      = GDK_KEY_Itilde,
    _Lcedilla                    = GDK_KEY_Lcedilla,
    _Emacron                     = GDK_KEY_Emacron,
    _Gcedilla                    = GDK_KEY_Gcedilla,
    _Tslash                      = GDK_KEY_Tslash,
    _rcedilla                    = GDK_KEY_rcedilla,
    _itilde                      = GDK_KEY_itilde,
    _lcedilla                    = GDK_KEY_lcedilla,
    _emacron                     = GDK_KEY_emacron,
    _gcedilla                    = GDK_KEY_gcedilla,
    _tslash                      = GDK_KEY_tslash,
    _ENG                         = GDK_KEY_ENG,
    _eng                         = GDK_KEY_eng,
    _Amacron                     = GDK_KEY_Amacron,
    _Iogonek                     = GDK_KEY_Iogonek,
    _Eabovedot                   = GDK_KEY_Eabovedot,
    _Imacron                     = GDK_KEY_Imacron,
    _Ncedilla                    = GDK_KEY_Ncedilla,
    _Omacron                     = GDK_KEY_Omacron,
    _Kcedilla                    = GDK_KEY_Kcedilla,
    _Uogonek                     = GDK_KEY_Uogonek,
    _Utilde                      = GDK_KEY_Utilde,
    _Umacron                     = GDK_KEY_Umacron,
    _amacron                     = GDK_KEY_amacron,
    _iogonek                     = GDK_KEY_iogonek,
    _eabovedot                   = GDK_KEY_eabovedot,
    _imacron                     = GDK_KEY_imacron,
    _ncedilla                    = GDK_KEY_ncedilla,
    _omacron                     = GDK_KEY_omacron,
    _kcedilla                    = GDK_KEY_kcedilla,
    _uogonek                     = GDK_KEY_uogonek,
    _utilde                      = GDK_KEY_utilde,
    _umacron                     = GDK_KEY_umacron,
    _Wcircumflex                 = GDK_KEY_Wcircumflex,
    _wcircumflex                 = GDK_KEY_wcircumflex,
    _Ycircumflex                 = GDK_KEY_Ycircumflex,
    _ycircumflex                 = GDK_KEY_ycircumflex,
    _Babovedot                   = GDK_KEY_Babovedot,
    _babovedot                   = GDK_KEY_babovedot,
    _Dabovedot                   = GDK_KEY_Dabovedot,
    _dabovedot                   = GDK_KEY_dabovedot,
    _Fabovedot                   = GDK_KEY_Fabovedot,
    _fabovedot                   = GDK_KEY_fabovedot,
    _Mabovedot                   = GDK_KEY_Mabovedot,
    _mabovedot                   = GDK_KEY_mabovedot,
    _Pabovedot                   = GDK_KEY_Pabovedot,
    _pabovedot                   = GDK_KEY_pabovedot,
    _Sabovedot                   = GDK_KEY_Sabovedot,
    _sabovedot                   = GDK_KEY_sabovedot,
    _Tabovedot                   = GDK_KEY_Tabovedot,
    _tabovedot                   = GDK_KEY_tabovedot,
    _Wgrave                      = GDK_KEY_Wgrave,
    _wgrave                      = GDK_KEY_wgrave,
    _Wacute                      = GDK_KEY_Wacute,
    _wacute                      = GDK_KEY_wacute,
    _Wdiaeresis                  = GDK_KEY_Wdiaeresis,
    _wdiaeresis                  = GDK_KEY_wdiaeresis,
    _Ygrave                      = GDK_KEY_Ygrave,
    _ygrave                      = GDK_KEY_ygrave,
    _OE                          = GDK_KEY_OE,
    _oe                          = GDK_KEY_oe,
    _Ydiaeresis                  = GDK_KEY_Ydiaeresis,
    _overline                    = GDK_KEY_overline,
    _kana_fullstop               = GDK_KEY_kana_fullstop,
    _kana_openingbracket         = GDK_KEY_kana_openingbracket,
    _kana_closingbracket         = GDK_KEY_kana_closingbracket,
    _kana_comma                  = GDK_KEY_kana_comma,
    _kana_conjunctive            = GDK_KEY_kana_conjunctive,
    _kana_middledot              = GDK_KEY_kana_middledot,
    _kana_WO                     = GDK_KEY_kana_WO,
    _kana_a                      = GDK_KEY_kana_a,
    _kana_i                      = GDK_KEY_kana_i,
    _kana_u                      = GDK_KEY_kana_u,
    _kana_e                      = GDK_KEY_kana_e,
    _kana_o                      = GDK_KEY_kana_o,
    _kana_ya                     = GDK_KEY_kana_ya,
    _kana_yu                     = GDK_KEY_kana_yu,
    _kana_yo                     = GDK_KEY_kana_yo,
    _kana_tsu                    = GDK_KEY_kana_tsu,
    _kana_tu                     = GDK_KEY_kana_tu,
    _prolongedsound              = GDK_KEY_prolongedsound,
    _kana_A                      = GDK_KEY_kana_A,
    _kana_I                      = GDK_KEY_kana_I,
    _kana_U                      = GDK_KEY_kana_U,
    _kana_E                      = GDK_KEY_kana_E,
    _kana_O                      = GDK_KEY_kana_O,
    _kana_KA                     = GDK_KEY_kana_KA,
    _kana_KI                     = GDK_KEY_kana_KI,
    _kana_KU                     = GDK_KEY_kana_KU,
    _kana_KE                     = GDK_KEY_kana_KE,
    _kana_KO                     = GDK_KEY_kana_KO,
    _kana_SA                     = GDK_KEY_kana_SA,
    _kana_SHI                    = GDK_KEY_kana_SHI,
    _kana_SU                     = GDK_KEY_kana_SU,
    _kana_SE                     = GDK_KEY_kana_SE,
    _kana_SO                     = GDK_KEY_kana_SO,
    _kana_TA                     = GDK_KEY_kana_TA,
    _kana_CHI                    = GDK_KEY_kana_CHI,
    _kana_TI                     = GDK_KEY_kana_TI,
    _kana_TSU                    = GDK_KEY_kana_TSU,
    _kana_TU                     = GDK_KEY_kana_TU,
    _kana_TE                     = GDK_KEY_kana_TE,
    _kana_TO                     = GDK_KEY_kana_TO,
    _kana_NA                     = GDK_KEY_kana_NA,
    _kana_NI                     = GDK_KEY_kana_NI,
    _kana_NU                     = GDK_KEY_kana_NU,
    _kana_NE                     = GDK_KEY_kana_NE,
    _kana_NO                     = GDK_KEY_kana_NO,
    _kana_HA                     = GDK_KEY_kana_HA,
    _kana_HI                     = GDK_KEY_kana_HI,
    _kana_FU                     = GDK_KEY_kana_FU,
    _kana_HU                     = GDK_KEY_kana_HU,
    _kana_HE                     = GDK_KEY_kana_HE,
    _kana_HO                     = GDK_KEY_kana_HO,
    _kana_MA                     = GDK_KEY_kana_MA,
    _kana_MI                     = GDK_KEY_kana_MI,
    _kana_MU                     = GDK_KEY_kana_MU,
    _kana_ME                     = GDK_KEY_kana_ME,
    _kana_MO                     = GDK_KEY_kana_MO,
    _kana_YA                     = GDK_KEY_kana_YA,
    _kana_YU                     = GDK_KEY_kana_YU,
    _kana_YO                     = GDK_KEY_kana_YO,
    _kana_RA                     = GDK_KEY_kana_RA,
    _kana_RI                     = GDK_KEY_kana_RI,
    _kana_RU                     = GDK_KEY_kana_RU,
    _kana_RE                     = GDK_KEY_kana_RE,
    _kana_RO                     = GDK_KEY_kana_RO,
    _kana_WA                     = GDK_KEY_kana_WA,
    _kana_N                      = GDK_KEY_kana_N,
    _voicedsound                 = GDK_KEY_voicedsound,
    _semivoicedsound             = GDK_KEY_semivoicedsound,
    _kana_switch                 = GDK_KEY_kana_switch,
    _Farsi_0                     = GDK_KEY_Farsi_0,
    _Farsi_1                     = GDK_KEY_Farsi_1,
    _Farsi_2                     = GDK_KEY_Farsi_2,
    _Farsi_3                     = GDK_KEY_Farsi_3,
    _Farsi_4                     = GDK_KEY_Farsi_4,
    _Farsi_5                     = GDK_KEY_Farsi_5,
    _Farsi_6                     = GDK_KEY_Farsi_6,
    _Farsi_7                     = GDK_KEY_Farsi_7,
    _Farsi_8                     = GDK_KEY_Farsi_8,
    _Farsi_9                     = GDK_KEY_Farsi_9,
    _Arabic_percent              = GDK_KEY_Arabic_percent,
    _Arabic_superscript_alef     = GDK_KEY_Arabic_superscript_alef,
    _Arabic_tteh                 = GDK_KEY_Arabic_tteh,
    _Arabic_peh                  = GDK_KEY_Arabic_peh,
    _Arabic_tcheh                = GDK_KEY_Arabic_tcheh,
    _Arabic_ddal                 = GDK_KEY_Arabic_ddal,
    _Arabic_rreh                 = GDK_KEY_Arabic_rreh,
    _Arabic_comma                = GDK_KEY_Arabic_comma,
    _Arabic_fullstop             = GDK_KEY_Arabic_fullstop,
    _Arabic_0                    = GDK_KEY_Arabic_0,
    _Arabic_1                    = GDK_KEY_Arabic_1,
    _Arabic_2                    = GDK_KEY_Arabic_2,
    _Arabic_3                    = GDK_KEY_Arabic_3,
    _Arabic_4                    = GDK_KEY_Arabic_4,
    _Arabic_5                    = GDK_KEY_Arabic_5,
    _Arabic_6                    = GDK_KEY_Arabic_6,
    _Arabic_7                    = GDK_KEY_Arabic_7,
    _Arabic_8                    = GDK_KEY_Arabic_8,
    _Arabic_9                    = GDK_KEY_Arabic_9,
    _Arabic_semicolon            = GDK_KEY_Arabic_semicolon,
    _Arabic_question_mark        = GDK_KEY_Arabic_question_mark,
    _Arabic_hamza                = GDK_KEY_Arabic_hamza,
    _Arabic_maddaonalef          = GDK_KEY_Arabic_maddaonalef,
    _Arabic_hamzaonalef          = GDK_KEY_Arabic_hamzaonalef,
    _Arabic_hamzaonwaw           = GDK_KEY_Arabic_hamzaonwaw,
    _Arabic_hamzaunderalef       = GDK_KEY_Arabic_hamzaunderalef,
    _Arabic_hamzaonyeh           = GDK_KEY_Arabic_hamzaonyeh,
    _Arabic_alef                 = GDK_KEY_Arabic_alef,
    _Arabic_beh                  = GDK_KEY_Arabic_beh,
    _Arabic_tehmarbuta           = GDK_KEY_Arabic_tehmarbuta,
    _Arabic_teh                  = GDK_KEY_Arabic_teh,
    _Arabic_theh                 = GDK_KEY_Arabic_theh,
    _Arabic_jeem                 = GDK_KEY_Arabic_jeem,
    _Arabic_hah                  = GDK_KEY_Arabic_hah,
    _Arabic_khah                 = GDK_KEY_Arabic_khah,
    _Arabic_dal                  = GDK_KEY_Arabic_dal,
    _Arabic_thal                 = GDK_KEY_Arabic_thal,
    _Arabic_ra                   = GDK_KEY_Arabic_ra,
    _Arabic_zain                 = GDK_KEY_Arabic_zain,
    _Arabic_seen                 = GDK_KEY_Arabic_seen,
    _Arabic_sheen                = GDK_KEY_Arabic_sheen,
    _Arabic_sad                  = GDK_KEY_Arabic_sad,
    _Arabic_dad                  = GDK_KEY_Arabic_dad,
    _Arabic_tah                  = GDK_KEY_Arabic_tah,
    _Arabic_zah                  = GDK_KEY_Arabic_zah,
    _Arabic_ain                  = GDK_KEY_Arabic_ain,
    _Arabic_ghain                = GDK_KEY_Arabic_ghain,
    _Arabic_tatweel              = GDK_KEY_Arabic_tatweel,
    _Arabic_feh                  = GDK_KEY_Arabic_feh,
    _Arabic_qaf                  = GDK_KEY_Arabic_qaf,
    _Arabic_kaf                  = GDK_KEY_Arabic_kaf,
    _Arabic_lam                  = GDK_KEY_Arabic_lam,
    _Arabic_meem                 = GDK_KEY_Arabic_meem,
    _Arabic_noon                 = GDK_KEY_Arabic_noon,
    _Arabic_ha                   = GDK_KEY_Arabic_ha,
    _Arabic_heh                  = GDK_KEY_Arabic_heh,
    _Arabic_waw                  = GDK_KEY_Arabic_waw,
    _Arabic_alefmaksura          = GDK_KEY_Arabic_alefmaksura,
    _Arabic_yeh                  = GDK_KEY_Arabic_yeh,
    _Arabic_fathatan             = GDK_KEY_Arabic_fathatan,
    _Arabic_dammatan             = GDK_KEY_Arabic_dammatan,
    _Arabic_kasratan             = GDK_KEY_Arabic_kasratan,
    _Arabic_fatha                = GDK_KEY_Arabic_fatha,
    _Arabic_damma                = GDK_KEY_Arabic_damma,
    _Arabic_kasra                = GDK_KEY_Arabic_kasra,
    _Arabic_shadda               = GDK_KEY_Arabic_shadda,
    _Arabic_sukun                = GDK_KEY_Arabic_sukun,
    _Arabic_madda_above          = GDK_KEY_Arabic_madda_above,
    _Arabic_hamza_above          = GDK_KEY_Arabic_hamza_above,
    _Arabic_hamza_below          = GDK_KEY_Arabic_hamza_below,
    _Arabic_jeh                  = GDK_KEY_Arabic_jeh,
    _Arabic_veh                  = GDK_KEY_Arabic_veh,
    _Arabic_keheh                = GDK_KEY_Arabic_keheh,
    _Arabic_gaf                  = GDK_KEY_Arabic_gaf,
    _Arabic_noon_ghunna          = GDK_KEY_Arabic_noon_ghunna,
    _Arabic_heh_doachashmee      = GDK_KEY_Arabic_heh_doachashmee,
    _Farsi_yeh                   = GDK_KEY_Farsi_yeh,
    _Arabic_farsi_yeh            = GDK_KEY_Arabic_farsi_yeh,
    _Arabic_yeh_baree            = GDK_KEY_Arabic_yeh_baree,
    _Arabic_heh_goal             = GDK_KEY_Arabic_heh_goal,
    _Arabic_switch               = GDK_KEY_Arabic_switch,
    _Cyrillic_GHE_bar            = GDK_KEY_Cyrillic_GHE_bar,
    _Cyrillic_ghe_bar            = GDK_KEY_Cyrillic_ghe_bar,
    _Cyrillic_ZHE_descender      = GDK_KEY_Cyrillic_ZHE_descender,
    _Cyrillic_zhe_descender      = GDK_KEY_Cyrillic_zhe_descender,
    _Cyrillic_KA_descender       = GDK_KEY_Cyrillic_KA_descender,
    _Cyrillic_ka_descender       = GDK_KEY_Cyrillic_ka_descender,
    _Cyrillic_KA_vertstroke      = GDK_KEY_Cyrillic_KA_vertstroke,
    _Cyrillic_ka_vertstroke      = GDK_KEY_Cyrillic_ka_vertstroke,
    _Cyrillic_EN_descender       = GDK_KEY_Cyrillic_EN_descender,
    _Cyrillic_en_descender       = GDK_KEY_Cyrillic_en_descender,
    _Cyrillic_U_straight         = GDK_KEY_Cyrillic_U_straight,
    _Cyrillic_u_straight         = GDK_KEY_Cyrillic_u_straight,
    _Cyrillic_U_straight_bar     = GDK_KEY_Cyrillic_U_straight_bar,
    _Cyrillic_u_straight_bar     = GDK_KEY_Cyrillic_u_straight_bar,
    _Cyrillic_HA_descender       = GDK_KEY_Cyrillic_HA_descender,
    _Cyrillic_ha_descender       = GDK_KEY_Cyrillic_ha_descender,
    _Cyrillic_CHE_descender      = GDK_KEY_Cyrillic_CHE_descender,
    _Cyrillic_che_descender      = GDK_KEY_Cyrillic_che_descender,
    _Cyrillic_CHE_vertstroke     = GDK_KEY_Cyrillic_CHE_vertstroke,
    _Cyrillic_che_vertstroke     = GDK_KEY_Cyrillic_che_vertstroke,
    _Cyrillic_SHHA               = GDK_KEY_Cyrillic_SHHA,
    _Cyrillic_shha               = GDK_KEY_Cyrillic_shha,
    _Cyrillic_SCHWA              = GDK_KEY_Cyrillic_SCHWA,
    _Cyrillic_schwa              = GDK_KEY_Cyrillic_schwa,
    _Cyrillic_I_macron           = GDK_KEY_Cyrillic_I_macron,
    _Cyrillic_i_macron           = GDK_KEY_Cyrillic_i_macron,
    _Cyrillic_O_bar              = GDK_KEY_Cyrillic_O_bar,
    _Cyrillic_o_bar              = GDK_KEY_Cyrillic_o_bar,
    _Cyrillic_U_macron           = GDK_KEY_Cyrillic_U_macron,
    _Cyrillic_u_macron           = GDK_KEY_Cyrillic_u_macron,
    _Serbian_dje                 = GDK_KEY_Serbian_dje,
    _Macedonia_gje               = GDK_KEY_Macedonia_gje,
    _Cyrillic_io                 = GDK_KEY_Cyrillic_io,
    _Ukrainian_ie                = GDK_KEY_Ukrainian_ie,
    _Ukranian_je                 = GDK_KEY_Ukranian_je,
    _Macedonia_dse               = GDK_KEY_Macedonia_dse,
    _Ukrainian_i                 = GDK_KEY_Ukrainian_i,
    _Ukranian_i                  = GDK_KEY_Ukranian_i,
    _Ukrainian_yi                = GDK_KEY_Ukrainian_yi,
    _Ukranian_yi                 = GDK_KEY_Ukranian_yi,
    _Cyrillic_je                 = GDK_KEY_Cyrillic_je,
    _Serbian_je                  = GDK_KEY_Serbian_je,
    _Cyrillic_lje                = GDK_KEY_Cyrillic_lje,
    _Serbian_lje                 = GDK_KEY_Serbian_lje,
    _Cyrillic_nje                = GDK_KEY_Cyrillic_nje,
    _Serbian_nje                 = GDK_KEY_Serbian_nje,
    _Serbian_tshe                = GDK_KEY_Serbian_tshe,
    _Macedonia_kje               = GDK_KEY_Macedonia_kje,
    _Ukrainian_ghe_with_upturn   = GDK_KEY_Ukrainian_ghe_with_upturn,
    _Byelorussian_shortu         = GDK_KEY_Byelorussian_shortu,
    _Cyrillic_dzhe               = GDK_KEY_Cyrillic_dzhe,
    _Serbian_dze                 = GDK_KEY_Serbian_dze,
    _numerosign                  = GDK_KEY_numerosign,
    _Serbian_DJE                 = GDK_KEY_Serbian_DJE,
    _Macedonia_GJE               = GDK_KEY_Macedonia_GJE,
    _Cyrillic_IO                 = GDK_KEY_Cyrillic_IO,
    _Ukrainian_IE                = GDK_KEY_Ukrainian_IE,
    _Ukranian_JE                 = GDK_KEY_Ukranian_JE,
    _Macedonia_DSE               = GDK_KEY_Macedonia_DSE,
    _Ukrainian_I                 = GDK_KEY_Ukrainian_I,
    _Ukranian_I                  = GDK_KEY_Ukranian_I,
    _Ukrainian_YI                = GDK_KEY_Ukrainian_YI,
    _Ukranian_YI                 = GDK_KEY_Ukranian_YI,
    _Cyrillic_JE                 = GDK_KEY_Cyrillic_JE,
    _Serbian_JE                  = GDK_KEY_Serbian_JE,
    _Cyrillic_LJE                = GDK_KEY_Cyrillic_LJE,
    _Serbian_LJE                 = GDK_KEY_Serbian_LJE,
    _Cyrillic_NJE                = GDK_KEY_Cyrillic_NJE,
    _Serbian_NJE                 = GDK_KEY_Serbian_NJE,
    _Serbian_TSHE                = GDK_KEY_Serbian_TSHE,
    _Macedonia_KJE               = GDK_KEY_Macedonia_KJE,
    _Ukrainian_GHE_WITH_UPTURN   = GDK_KEY_Ukrainian_GHE_WITH_UPTURN,
    _Byelorussian_SHORTU         = GDK_KEY_Byelorussian_SHORTU,
    _Cyrillic_DZHE               = GDK_KEY_Cyrillic_DZHE,
    _Serbian_DZE                 = GDK_KEY_Serbian_DZE,
    _Cyrillic_yu                 = GDK_KEY_Cyrillic_yu,
    _Cyrillic_a                  = GDK_KEY_Cyrillic_a,
    _Cyrillic_be                 = GDK_KEY_Cyrillic_be,
    _Cyrillic_tse                = GDK_KEY_Cyrillic_tse,
    _Cyrillic_de                 = GDK_KEY_Cyrillic_de,
    _Cyrillic_ie                 = GDK_KEY_Cyrillic_ie,
    _Cyrillic_ef                 = GDK_KEY_Cyrillic_ef,
    _Cyrillic_ghe                = GDK_KEY_Cyrillic_ghe,
    _Cyrillic_ha                 = GDK_KEY_Cyrillic_ha,
    _Cyrillic_i                  = GDK_KEY_Cyrillic_i,
    _Cyrillic_shorti             = GDK_KEY_Cyrillic_shorti,
    _Cyrillic_ka                 = GDK_KEY_Cyrillic_ka,
    _Cyrillic_el                 = GDK_KEY_Cyrillic_el,
    _Cyrillic_em                 = GDK_KEY_Cyrillic_em,
    _Cyrillic_en                 = GDK_KEY_Cyrillic_en,
    _Cyrillic_o                  = GDK_KEY_Cyrillic_o,
    _Cyrillic_pe                 = GDK_KEY_Cyrillic_pe,
    _Cyrillic_ya                 = GDK_KEY_Cyrillic_ya,
    _Cyrillic_er                 = GDK_KEY_Cyrillic_er,
    _Cyrillic_es                 = GDK_KEY_Cyrillic_es,
    _Cyrillic_te                 = GDK_KEY_Cyrillic_te,
    _Cyrillic_u                  = GDK_KEY_Cyrillic_u,
    _Cyrillic_zhe                = GDK_KEY_Cyrillic_zhe,
    _Cyrillic_ve                 = GDK_KEY_Cyrillic_ve,
    _Cyrillic_softsign           = GDK_KEY_Cyrillic_softsign,
    _Cyrillic_yeru               = GDK_KEY_Cyrillic_yeru,
    _Cyrillic_ze                 = GDK_KEY_Cyrillic_ze,
    _Cyrillic_sha                = GDK_KEY_Cyrillic_sha,
    _Cyrillic_e                  = GDK_KEY_Cyrillic_e,
    _Cyrillic_shcha              = GDK_KEY_Cyrillic_shcha,
    _Cyrillic_che                = GDK_KEY_Cyrillic_che,
    _Cyrillic_hardsign           = GDK_KEY_Cyrillic_hardsign,
    _Cyrillic_YU                 = GDK_KEY_Cyrillic_YU,
    _Cyrillic_A                  = GDK_KEY_Cyrillic_A,
    _Cyrillic_BE                 = GDK_KEY_Cyrillic_BE,
    _Cyrillic_TSE                = GDK_KEY_Cyrillic_TSE,
    _Cyrillic_DE                 = GDK_KEY_Cyrillic_DE,
    _Cyrillic_IE                 = GDK_KEY_Cyrillic_IE,
    _Cyrillic_EF                 = GDK_KEY_Cyrillic_EF,
    _Cyrillic_GHE                = GDK_KEY_Cyrillic_GHE,
    _Cyrillic_HA                 = GDK_KEY_Cyrillic_HA,
    _Cyrillic_I                  = GDK_KEY_Cyrillic_I,
    _Cyrillic_SHORTI             = GDK_KEY_Cyrillic_SHORTI,
    _Cyrillic_KA                 = GDK_KEY_Cyrillic_KA,
    _Cyrillic_EL                 = GDK_KEY_Cyrillic_EL,
    _Cyrillic_EM                 = GDK_KEY_Cyrillic_EM,
    _Cyrillic_EN                 = GDK_KEY_Cyrillic_EN,
    _Cyrillic_O                  = GDK_KEY_Cyrillic_O,
    _Cyrillic_PE                 = GDK_KEY_Cyrillic_PE,
    _Cyrillic_YA                 = GDK_KEY_Cyrillic_YA,
    _Cyrillic_ER                 = GDK_KEY_Cyrillic_ER,
    _Cyrillic_ES                 = GDK_KEY_Cyrillic_ES,
    _Cyrillic_TE                 = GDK_KEY_Cyrillic_TE,
    _Cyrillic_U                  = GDK_KEY_Cyrillic_U,
    _Cyrillic_ZHE                = GDK_KEY_Cyrillic_ZHE,
    _Cyrillic_VE                 = GDK_KEY_Cyrillic_VE,
    _Cyrillic_SOFTSIGN           = GDK_KEY_Cyrillic_SOFTSIGN,
    _Cyrillic_YERU               = GDK_KEY_Cyrillic_YERU,
    _Cyrillic_ZE                 = GDK_KEY_Cyrillic_ZE,
    _Cyrillic_SHA                = GDK_KEY_Cyrillic_SHA,
    _Cyrillic_E                  = GDK_KEY_Cyrillic_E,
    _Cyrillic_SHCHA              = GDK_KEY_Cyrillic_SHCHA,
    _Cyrillic_CHE                = GDK_KEY_Cyrillic_CHE,
    _Cyrillic_HARDSIGN           = GDK_KEY_Cyrillic_HARDSIGN,
    _Greek_ALPHAaccent           = GDK_KEY_Greek_ALPHAaccent,
    _Greek_EPSILONaccent         = GDK_KEY_Greek_EPSILONaccent,
    _Greek_ETAaccent             = GDK_KEY_Greek_ETAaccent,
    _Greek_IOTAaccent            = GDK_KEY_Greek_IOTAaccent,
    _Greek_IOTAdieresis          = GDK_KEY_Greek_IOTAdieresis,
    _Greek_IOTAdiaeresis         = GDK_KEY_Greek_IOTAdiaeresis,
    _Greek_OMICRONaccent         = GDK_KEY_Greek_OMICRONaccent,
    _Greek_UPSILONaccent         = GDK_KEY_Greek_UPSILONaccent,
    _Greek_UPSILONdieresis       = GDK_KEY_Greek_UPSILONdieresis,
    _Greek_OMEGAaccent           = GDK_KEY_Greek_OMEGAaccent,
    _Greek_accentdieresis        = GDK_KEY_Greek_accentdieresis,
    _Greek_horizbar              = GDK_KEY_Greek_horizbar,
    _Greek_alphaaccent           = GDK_KEY_Greek_alphaaccent,
    _Greek_epsilonaccent         = GDK_KEY_Greek_epsilonaccent,
    _Greek_etaaccent             = GDK_KEY_Greek_etaaccent,
    _Greek_iotaaccent            = GDK_KEY_Greek_iotaaccent,
    _Greek_iotadieresis          = GDK_KEY_Greek_iotadieresis,
    _Greek_iotaaccentdieresis    = GDK_KEY_Greek_iotaaccentdieresis,
    _Greek_omicronaccent         = GDK_KEY_Greek_omicronaccent,
    _Greek_upsilonaccent         = GDK_KEY_Greek_upsilonaccent,
    _Greek_upsilondieresis       = GDK_KEY_Greek_upsilondieresis,
    _Greek_upsilonaccentdieresis = GDK_KEY_Greek_upsilonaccentdieresis,
    _Greek_omegaaccent           = GDK_KEY_Greek_omegaaccent,
    _Greek_ALPHA                 = GDK_KEY_Greek_ALPHA,
    _Greek_BETA                  = GDK_KEY_Greek_BETA,
    _Greek_GAMMA                 = GDK_KEY_Greek_GAMMA,
    _Greek_DELTA                 = GDK_KEY_Greek_DELTA,
    _Greek_EPSILON               = GDK_KEY_Greek_EPSILON,
    _Greek_ZETA                  = GDK_KEY_Greek_ZETA,
    _Greek_ETA                   = GDK_KEY_Greek_ETA,
    _Greek_THETA                 = GDK_KEY_Greek_THETA,
    _Greek_IOTA                  = GDK_KEY_Greek_IOTA,
    _Greek_KAPPA                 = GDK_KEY_Greek_KAPPA,
    _Greek_LAMDA                 = GDK_KEY_Greek_LAMDA,
    _Greek_LAMBDA                = GDK_KEY_Greek_LAMBDA,
    _Greek_MU                    = GDK_KEY_Greek_MU,
    _Greek_NU                    = GDK_KEY_Greek_NU,
    _Greek_XI                    = GDK_KEY_Greek_XI,
    _Greek_OMICRON               = GDK_KEY_Greek_OMICRON,
    _Greek_PI                    = GDK_KEY_Greek_PI,
    _Greek_RHO                   = GDK_KEY_Greek_RHO,
    _Greek_SIGMA                 = GDK_KEY_Greek_SIGMA,
    _Greek_TAU                   = GDK_KEY_Greek_TAU,
    _Greek_UPSILON               = GDK_KEY_Greek_UPSILON,
    _Greek_PHI                   = GDK_KEY_Greek_PHI,
    _Greek_CHI                   = GDK_KEY_Greek_CHI,
    _Greek_PSI                   = GDK_KEY_Greek_PSI,
    _Greek_OMEGA                 = GDK_KEY_Greek_OMEGA,
    _Greek_alpha                 = GDK_KEY_Greek_alpha,
    _Greek_beta                  = GDK_KEY_Greek_beta,
    _Greek_gamma                 = GDK_KEY_Greek_gamma,
    _Greek_delta                 = GDK_KEY_Greek_delta,
    _Greek_epsilon               = GDK_KEY_Greek_epsilon,
    _Greek_zeta                  = GDK_KEY_Greek_zeta,
    _Greek_eta                   = GDK_KEY_Greek_eta,
    _Greek_theta                 = GDK_KEY_Greek_theta,
    _Greek_iota                  = GDK_KEY_Greek_iota,
    _Greek_kappa                 = GDK_KEY_Greek_kappa,
    _Greek_lamda                 = GDK_KEY_Greek_lamda,
    _Greek_lambda                = GDK_KEY_Greek_lambda,
    _Greek_mu                    = GDK_KEY_Greek_mu,
    _Greek_nu                    = GDK_KEY_Greek_nu,
    _Greek_xi                    = GDK_KEY_Greek_xi,
    _Greek_omicron               = GDK_KEY_Greek_omicron,
    _Greek_pi                    = GDK_KEY_Greek_pi,
    _Greek_rho                   = GDK_KEY_Greek_rho,
    _Greek_sigma                 = GDK_KEY_Greek_sigma,
    _Greek_finalsmallsigma       = GDK_KEY_Greek_finalsmallsigma,
    _Greek_tau                   = GDK_KEY_Greek_tau,
    _Greek_upsilon               = GDK_KEY_Greek_upsilon,
    _Greek_phi                   = GDK_KEY_Greek_phi,
    _Greek_chi                   = GDK_KEY_Greek_chi,
    _Greek_psi                   = GDK_KEY_Greek_psi,
    _Greek_omega                 = GDK_KEY_Greek_omega,
    _Greek_switch                = GDK_KEY_Greek_switch,
    _leftradical                 = GDK_KEY_leftradical,
    _topleftradical              = GDK_KEY_topleftradical,
    _horizconnector              = GDK_KEY_horizconnector,
    _topintegral                 = GDK_KEY_topintegral,
    _botintegral                 = GDK_KEY_botintegral,
    _vertconnector               = GDK_KEY_vertconnector,
    _topleftsqbracket            = GDK_KEY_topleftsqbracket,
    _botleftsqbracket            = GDK_KEY_botleftsqbracket,
    _toprightsqbracket           = GDK_KEY_toprightsqbracket,
    _botrightsqbracket           = GDK_KEY_botrightsqbracket,
    _topleftparens               = GDK_KEY_topleftparens,
    _botleftparens               = GDK_KEY_botleftparens,
    _toprightparens              = GDK_KEY_toprightparens,
    _botrightparens              = GDK_KEY_botrightparens,
    _leftmiddlecurlybrace        = GDK_KEY_leftmiddlecurlybrace,
    _rightmiddlecurlybrace       = GDK_KEY_rightmiddlecurlybrace,
    _topleftsummation            = GDK_KEY_topleftsummation,
    _botleftsummation            = GDK_KEY_botleftsummation,
    _topvertsummationconnector   = GDK_KEY_topvertsummationconnector,
    _botvertsummationconnector   = GDK_KEY_botvertsummationconnector,
    _toprightsummation           = GDK_KEY_toprightsummation,
    _botrightsummation           = GDK_KEY_botrightsummation,
    _rightmiddlesummation        = GDK_KEY_rightmiddlesummation,
    _lessthanequal               = GDK_KEY_lessthanequal,
    _notequal                    = GDK_KEY_notequal,
    _greaterthanequal            = GDK_KEY_greaterthanequal,
    _integral                    = GDK_KEY_integral,
    _therefore                   = GDK_KEY_therefore,
    _variation                   = GDK_KEY_variation,
    _infinity                    = GDK_KEY_infinity,
    _nabla                       = GDK_KEY_nabla,
    _approximate                 = GDK_KEY_approximate,
    _similarequal                = GDK_KEY_similarequal,
    _ifonlyif                    = GDK_KEY_ifonlyif,
    _implies                     = GDK_KEY_implies,
    _identical                   = GDK_KEY_identical,
    _radical                     = GDK_KEY_radical,
    _includedin                  = GDK_KEY_includedin,
    _includes                    = GDK_KEY_includes,
    _intersection                = GDK_KEY_intersection,
    _union                       = GDK_KEY_union,
    _logicaland                  = GDK_KEY_logicaland,
    _logicalor                   = GDK_KEY_logicalor,
    _partialderivative           = GDK_KEY_partialderivative,
    _function                    = GDK_KEY_function,
    _leftarrow                   = GDK_KEY_leftarrow,
    _uparrow                     = GDK_KEY_uparrow,
    _rightarrow                  = GDK_KEY_rightarrow,
    _downarrow                   = GDK_KEY_downarrow,
    _blank                       = GDK_KEY_blank,
    _soliddiamond                = GDK_KEY_soliddiamond,
    _checkerboard                = GDK_KEY_checkerboard,
    _ht                          = GDK_KEY_ht,
    _ff                          = GDK_KEY_ff,
    _cr                          = GDK_KEY_cr,
    _lf                          = GDK_KEY_lf,
    _nl                          = GDK_KEY_nl,
    _vt                          = GDK_KEY_vt,
    _lowrightcorner              = GDK_KEY_lowrightcorner,
    _uprightcorner               = GDK_KEY_uprightcorner,
    _upleftcorner                = GDK_KEY_upleftcorner,
    _lowleftcorner               = GDK_KEY_lowleftcorner,
    _crossinglines               = GDK_KEY_crossinglines,
    _horizlinescan1              = GDK_KEY_horizlinescan1,
    _horizlinescan3              = GDK_KEY_horizlinescan3,
    _horizlinescan5              = GDK_KEY_horizlinescan5,
    _horizlinescan7              = GDK_KEY_horizlinescan7,
    _horizlinescan9              = GDK_KEY_horizlinescan9,
    _leftt                       = GDK_KEY_leftt,
    _rightt                      = GDK_KEY_rightt,
    _bott                        = GDK_KEY_bott,
    _topt                        = GDK_KEY_topt,
    _vertbar                     = GDK_KEY_vertbar,
    _emspace                     = GDK_KEY_emspace,
    _enspace                     = GDK_KEY_enspace,
    _em3space                    = GDK_KEY_em3space,
    _em4space                    = GDK_KEY_em4space,
    _digitspace                  = GDK_KEY_digitspace,
    _punctspace                  = GDK_KEY_punctspace,
    _thinspace                   = GDK_KEY_thinspace,
    _hairspace                   = GDK_KEY_hairspace,
    _emdash                      = GDK_KEY_emdash,
    _endash                      = GDK_KEY_endash,
    _signifblank                 = GDK_KEY_signifblank,
    _ellipsis                    = GDK_KEY_ellipsis,
    _doubbaselinedot             = GDK_KEY_doubbaselinedot,
    _onethird                    = GDK_KEY_onethird,
    _twothirds                   = GDK_KEY_twothirds,
    _onefifth                    = GDK_KEY_onefifth,
    _twofifths                   = GDK_KEY_twofifths,
    _threefifths                 = GDK_KEY_threefifths,
    _fourfifths                  = GDK_KEY_fourfifths,
    _onesixth                    = GDK_KEY_onesixth,
    _fivesixths                  = GDK_KEY_fivesixths,
    _careof                      = GDK_KEY_careof,
    _figdash                     = GDK_KEY_figdash,
    _leftanglebracket            = GDK_KEY_leftanglebracket,
    _decimalpoint                = GDK_KEY_decimalpoint,
    _rightanglebracket           = GDK_KEY_rightanglebracket,
    _marker                      = GDK_KEY_marker,
    _oneeighth                   = GDK_KEY_oneeighth,
    _threeeighths                = GDK_KEY_threeeighths,
    _fiveeighths                 = GDK_KEY_fiveeighths,
    _seveneighths                = GDK_KEY_seveneighths,
    _trademark                   = GDK_KEY_trademark,
    _signaturemark               = GDK_KEY_signaturemark,
    _trademarkincircle           = GDK_KEY_trademarkincircle,
    _leftopentriangle            = GDK_KEY_leftopentriangle,
    _rightopentriangle           = GDK_KEY_rightopentriangle,
    _emopencircle                = GDK_KEY_emopencircle,
    _emopenrectangle             = GDK_KEY_emopenrectangle,
    _leftsinglequotemark         = GDK_KEY_leftsinglequotemark,
    _rightsinglequotemark        = GDK_KEY_rightsinglequotemark,
    _leftdoublequotemark         = GDK_KEY_leftdoublequotemark,
    _rightdoublequotemark        = GDK_KEY_rightdoublequotemark,
    _prescription                = GDK_KEY_prescription,
    _minutes                     = GDK_KEY_minutes,
    _seconds                     = GDK_KEY_seconds,
    _latincross                  = GDK_KEY_latincross,
    _hexagram                    = GDK_KEY_hexagram,
    _filledrectbullet            = GDK_KEY_filledrectbullet,
    _filledlefttribullet         = GDK_KEY_filledlefttribullet,
    _filledrighttribullet        = GDK_KEY_filledrighttribullet,
    _emfilledcircle              = GDK_KEY_emfilledcircle,
    _emfilledrect                = GDK_KEY_emfilledrect,
    _enopencircbullet            = GDK_KEY_enopencircbullet,
    _enopensquarebullet          = GDK_KEY_enopensquarebullet,
    _openrectbullet              = GDK_KEY_openrectbullet,
    _opentribulletup             = GDK_KEY_opentribulletup,
    _opentribulletdown           = GDK_KEY_opentribulletdown,
    _openstar                    = GDK_KEY_openstar,
    _enfilledcircbullet          = GDK_KEY_enfilledcircbullet,
    _enfilledsqbullet            = GDK_KEY_enfilledsqbullet,
    _filledtribulletup           = GDK_KEY_filledtribulletup,
    _filledtribulletdown         = GDK_KEY_filledtribulletdown,
    _leftpointer                 = GDK_KEY_leftpointer,
    _rightpointer                = GDK_KEY_rightpointer,
    _club                        = GDK_KEY_club,
    _diamond                     = GDK_KEY_diamond,
    _heart                       = GDK_KEY_heart,
    _maltesecross                = GDK_KEY_maltesecross,
    _dagger                      = GDK_KEY_dagger,
    _doubledagger                = GDK_KEY_doubledagger,
    _checkmark                   = GDK_KEY_checkmark,
    _ballotcross                 = GDK_KEY_ballotcross,
    _musicalsharp                = GDK_KEY_musicalsharp,
    _musicalflat                 = GDK_KEY_musicalflat,
    _malesymbol                  = GDK_KEY_malesymbol,
    _femalesymbol                = GDK_KEY_femalesymbol,
    _telephone                   = GDK_KEY_telephone,
    _telephonerecorder           = GDK_KEY_telephonerecorder,
    _phonographcopyright         = GDK_KEY_phonographcopyright,
    _caret                       = GDK_KEY_caret,
    _singlelowquotemark          = GDK_KEY_singlelowquotemark,
    _doublelowquotemark          = GDK_KEY_doublelowquotemark,
    _cursor                      = GDK_KEY_cursor,
    _leftcaret                   = GDK_KEY_leftcaret,
    _rightcaret                  = GDK_KEY_rightcaret,
    _downcaret                   = GDK_KEY_downcaret,
    _upcaret                     = GDK_KEY_upcaret,
    _overbar                     = GDK_KEY_overbar,
    _downtack                    = GDK_KEY_downtack,
    _upshoe                      = GDK_KEY_upshoe,
    _downstile                   = GDK_KEY_downstile,
    _underbar                    = GDK_KEY_underbar,
    _jot                         = GDK_KEY_jot,
    _quad                        = GDK_KEY_quad,
    _uptack                      = GDK_KEY_uptack,
    _circle                      = GDK_KEY_circle,
    _upstile                     = GDK_KEY_upstile,
    _downshoe                    = GDK_KEY_downshoe,
    _rightshoe                   = GDK_KEY_rightshoe,
    _leftshoe                    = GDK_KEY_leftshoe,
    _lefttack                    = GDK_KEY_lefttack,
    _righttack                   = GDK_KEY_righttack,
    _hebrew_doublelowline        = GDK_KEY_hebrew_doublelowline,
    _hebrew_aleph                = GDK_KEY_hebrew_aleph,
    _hebrew_bet                  = GDK_KEY_hebrew_bet,
    _hebrew_beth                 = GDK_KEY_hebrew_beth,
    _hebrew_gimel                = GDK_KEY_hebrew_gimel,
    _hebrew_gimmel               = GDK_KEY_hebrew_gimmel,
    _hebrew_dalet                = GDK_KEY_hebrew_dalet,
    _hebrew_daleth               = GDK_KEY_hebrew_daleth,
    _hebrew_he                   = GDK_KEY_hebrew_he,
    _hebrew_waw                  = GDK_KEY_hebrew_waw,
    _hebrew_zain                 = GDK_KEY_hebrew_zain,
    _hebrew_zayin                = GDK_KEY_hebrew_zayin,
    _hebrew_chet                 = GDK_KEY_hebrew_chet,
    _hebrew_het                  = GDK_KEY_hebrew_het,
    _hebrew_tet                  = GDK_KEY_hebrew_tet,
    _hebrew_teth                 = GDK_KEY_hebrew_teth,
    _hebrew_yod                  = GDK_KEY_hebrew_yod,
    _hebrew_finalkaph            = GDK_KEY_hebrew_finalkaph,
    _hebrew_kaph                 = GDK_KEY_hebrew_kaph,
    _hebrew_lamed                = GDK_KEY_hebrew_lamed,
    _hebrew_finalmem             = GDK_KEY_hebrew_finalmem,
    _hebrew_mem                  = GDK_KEY_hebrew_mem,
    _hebrew_finalnun             = GDK_KEY_hebrew_finalnun,
    _hebrew_nun                  = GDK_KEY_hebrew_nun,
    _hebrew_samech               = GDK_KEY_hebrew_samech,
    _hebrew_samekh               = GDK_KEY_hebrew_samekh,
    _hebrew_ayin                 = GDK_KEY_hebrew_ayin,
    _hebrew_finalpe              = GDK_KEY_hebrew_finalpe,
    _hebrew_pe                   = GDK_KEY_hebrew_pe,
    _hebrew_finalzade            = GDK_KEY_hebrew_finalzade,
    _hebrew_finalzadi            = GDK_KEY_hebrew_finalzadi,
    _hebrew_zade                 = GDK_KEY_hebrew_zade,
    _hebrew_zadi                 = GDK_KEY_hebrew_zadi,
    _hebrew_qoph                 = GDK_KEY_hebrew_qoph,
    _hebrew_kuf                  = GDK_KEY_hebrew_kuf,
    _hebrew_resh                 = GDK_KEY_hebrew_resh,
    _hebrew_shin                 = GDK_KEY_hebrew_shin,
    _hebrew_taw                  = GDK_KEY_hebrew_taw,
    _hebrew_taf                  = GDK_KEY_hebrew_taf,
    _Hebrew_switch               = GDK_KEY_Hebrew_switch,
    _Thai_kokai                  = GDK_KEY_Thai_kokai,
    _Thai_khokhai                = GDK_KEY_Thai_khokhai,
    _Thai_khokhuat               = GDK_KEY_Thai_khokhuat,
    _Thai_khokhwai               = GDK_KEY_Thai_khokhwai,
    _Thai_khokhon                = GDK_KEY_Thai_khokhon,
    _Thai_khorakhang             = GDK_KEY_Thai_khorakhang,
    _Thai_ngongu                 = GDK_KEY_Thai_ngongu,
    _Thai_chochan                = GDK_KEY_Thai_chochan,
    _Thai_choching               = GDK_KEY_Thai_choching,
    _Thai_chochang               = GDK_KEY_Thai_chochang,
    _Thai_soso                   = GDK_KEY_Thai_soso,
    _Thai_chochoe                = GDK_KEY_Thai_chochoe,
    _Thai_yoying                 = GDK_KEY_Thai_yoying,
    _Thai_dochada                = GDK_KEY_Thai_dochada,
    _Thai_topatak                = GDK_KEY_Thai_topatak,
    _Thai_thothan                = GDK_KEY_Thai_thothan,
    _Thai_thonangmontho          = GDK_KEY_Thai_thonangmontho,
    _Thai_thophuthao             = GDK_KEY_Thai_thophuthao,
    _Thai_nonen                  = GDK_KEY_Thai_nonen,
    _Thai_dodek                  = GDK_KEY_Thai_dodek,
    _Thai_totao                  = GDK_KEY_Thai_totao,
    _Thai_thothung               = GDK_KEY_Thai_thothung,
    _Thai_thothahan              = GDK_KEY_Thai_thothahan,
    _Thai_thothong               = GDK_KEY_Thai_thothong,
    _Thai_nonu                   = GDK_KEY_Thai_nonu,
    _Thai_bobaimai               = GDK_KEY_Thai_bobaimai,
    _Thai_popla                  = GDK_KEY_Thai_popla,
    _Thai_phophung               = GDK_KEY_Thai_phophung,
    _Thai_fofa                   = GDK_KEY_Thai_fofa,
    _Thai_phophan                = GDK_KEY_Thai_phophan,
    _Thai_fofan                  = GDK_KEY_Thai_fofan,
    _Thai_phosamphao             = GDK_KEY_Thai_phosamphao,
    _Thai_moma                   = GDK_KEY_Thai_moma,
    _Thai_yoyak                  = GDK_KEY_Thai_yoyak,
    _Thai_rorua                  = GDK_KEY_Thai_rorua,
    _Thai_ru                     = GDK_KEY_Thai_ru,
    _Thai_loling                 = GDK_KEY_Thai_loling,
    _Thai_lu                     = GDK_KEY_Thai_lu,
    _Thai_wowaen                 = GDK_KEY_Thai_wowaen,
    _Thai_sosala                 = GDK_KEY_Thai_sosala,
    _Thai_sorusi                 = GDK_KEY_Thai_sorusi,
    _Thai_sosua                  = GDK_KEY_Thai_sosua,
    _Thai_hohip                  = GDK_KEY_Thai_hohip,
    _Thai_lochula                = GDK_KEY_Thai_lochula,
    _Thai_oang                   = GDK_KEY_Thai_oang,
    _Thai_honokhuk               = GDK_KEY_Thai_honokhuk,
    _Thai_paiyannoi              = GDK_KEY_Thai_paiyannoi,
    _Thai_saraa                  = GDK_KEY_Thai_saraa,
    _Thai_maihanakat             = GDK_KEY_Thai_maihanakat,
    _Thai_saraaa                 = GDK_KEY_Thai_saraaa,
    _Thai_saraam                 = GDK_KEY_Thai_saraam,
    _Thai_sarai                  = GDK_KEY_Thai_sarai,
    _Thai_saraii                 = GDK_KEY_Thai_saraii,
    _Thai_saraue                 = GDK_KEY_Thai_saraue,
    _Thai_sarauee                = GDK_KEY_Thai_sarauee,
    _Thai_sarau                  = GDK_KEY_Thai_sarau,
    _Thai_sarauu                 = GDK_KEY_Thai_sarauu,
    _Thai_phinthu                = GDK_KEY_Thai_phinthu,
    _Thai_maihanakat_maitho      = GDK_KEY_Thai_maihanakat_maitho,
    _Thai_baht                   = GDK_KEY_Thai_baht,
    _Thai_sarae                  = GDK_KEY_Thai_sarae,
    _Thai_saraae                 = GDK_KEY_Thai_saraae,
    _Thai_sarao                  = GDK_KEY_Thai_sarao,
    _Thai_saraaimaimuan          = GDK_KEY_Thai_saraaimaimuan,
    _Thai_saraaimaimalai         = GDK_KEY_Thai_saraaimaimalai,
    _Thai_lakkhangyao            = GDK_KEY_Thai_lakkhangyao,
    _Thai_maiyamok               = GDK_KEY_Thai_maiyamok,
    _Thai_maitaikhu              = GDK_KEY_Thai_maitaikhu,
    _Thai_maiek                  = GDK_KEY_Thai_maiek,
    _Thai_maitho                 = GDK_KEY_Thai_maitho,
    _Thai_maitri                 = GDK_KEY_Thai_maitri,
    _Thai_maichattawa            = GDK_KEY_Thai_maichattawa,
    _Thai_thanthakhat            = GDK_KEY_Thai_thanthakhat,
    _Thai_nikhahit               = GDK_KEY_Thai_nikhahit,
    _Thai_leksun                 = GDK_KEY_Thai_leksun,
    _Thai_leknung                = GDK_KEY_Thai_leknung,
    _Thai_leksong                = GDK_KEY_Thai_leksong,
    _Thai_leksam                 = GDK_KEY_Thai_leksam,
    _Thai_leksi                  = GDK_KEY_Thai_leksi,
    _Thai_lekha                  = GDK_KEY_Thai_lekha,
    _Thai_lekhok                 = GDK_KEY_Thai_lekhok,
    _Thai_lekchet                = GDK_KEY_Thai_lekchet,
    _Thai_lekpaet                = GDK_KEY_Thai_lekpaet,
    _Thai_lekkao                 = GDK_KEY_Thai_lekkao,
    _Hangul                      = GDK_KEY_Hangul,
    _Hangul_Start                = GDK_KEY_Hangul_Start,
    _Hangul_End                  = GDK_KEY_Hangul_End,
    _Hangul_Hanja                = GDK_KEY_Hangul_Hanja,
    _Hangul_Jamo                 = GDK_KEY_Hangul_Jamo,
    _Hangul_Romaja               = GDK_KEY_Hangul_Romaja,
    _Hangul_Codeinput            = GDK_KEY_Hangul_Codeinput,
    _Hangul_Jeonja               = GDK_KEY_Hangul_Jeonja,
    _Hangul_Banja                = GDK_KEY_Hangul_Banja,
    _Hangul_PreHanja             = GDK_KEY_Hangul_PreHanja,
    _Hangul_PostHanja            = GDK_KEY_Hangul_PostHanja,
    _Hangul_SingleCandidate      = GDK_KEY_Hangul_SingleCandidate,
    _Hangul_MultipleCandidate    = GDK_KEY_Hangul_MultipleCandidate,
    _Hangul_PreviousCandidate    = GDK_KEY_Hangul_PreviousCandidate,
    _Hangul_Special              = GDK_KEY_Hangul_Special,
    _Hangul_switch               = GDK_KEY_Hangul_switch,
    _Hangul_Kiyeog               = GDK_KEY_Hangul_Kiyeog,
    _Hangul_SsangKiyeog          = GDK_KEY_Hangul_SsangKiyeog,
    _Hangul_KiyeogSios           = GDK_KEY_Hangul_KiyeogSios,
    _Hangul_Nieun                = GDK_KEY_Hangul_Nieun,
    _Hangul_NieunJieuj           = GDK_KEY_Hangul_NieunJieuj,
    _Hangul_NieunHieuh           = GDK_KEY_Hangul_NieunHieuh,
    _Hangul_Dikeud               = GDK_KEY_Hangul_Dikeud,
    _Hangul_SsangDikeud          = GDK_KEY_Hangul_SsangDikeud,
    _Hangul_Rieul                = GDK_KEY_Hangul_Rieul,
    _Hangul_RieulKiyeog          = GDK_KEY_Hangul_RieulKiyeog,
    _Hangul_RieulMieum           = GDK_KEY_Hangul_RieulMieum,
    _Hangul_RieulPieub           = GDK_KEY_Hangul_RieulPieub,
    _Hangul_RieulSios            = GDK_KEY_Hangul_RieulSios,
    _Hangul_RieulTieut           = GDK_KEY_Hangul_RieulTieut,
    _Hangul_RieulPhieuf          = GDK_KEY_Hangul_RieulPhieuf,
    _Hangul_RieulHieuh           = GDK_KEY_Hangul_RieulHieuh,
    _Hangul_Mieum                = GDK_KEY_Hangul_Mieum,
    _Hangul_Pieub                = GDK_KEY_Hangul_Pieub,
    _Hangul_SsangPieub           = GDK_KEY_Hangul_SsangPieub,
    _Hangul_PieubSios            = GDK_KEY_Hangul_PieubSios,
    _Hangul_Sios                 = GDK_KEY_Hangul_Sios,
    _Hangul_SsangSios            = GDK_KEY_Hangul_SsangSios,
    _Hangul_Ieung                = GDK_KEY_Hangul_Ieung,
    _Hangul_Jieuj                = GDK_KEY_Hangul_Jieuj,
    _Hangul_SsangJieuj           = GDK_KEY_Hangul_SsangJieuj,
    _Hangul_Cieuc                = GDK_KEY_Hangul_Cieuc,
    _Hangul_Khieuq               = GDK_KEY_Hangul_Khieuq,
    _Hangul_Tieut                = GDK_KEY_Hangul_Tieut,
    _Hangul_Phieuf               = GDK_KEY_Hangul_Phieuf,
    _Hangul_Hieuh                = GDK_KEY_Hangul_Hieuh,
    _Hangul_A                    = GDK_KEY_Hangul_A,
    _Hangul_AE                   = GDK_KEY_Hangul_AE,
    _Hangul_YA                   = GDK_KEY_Hangul_YA,
    _Hangul_YAE                  = GDK_KEY_Hangul_YAE,
    _Hangul_EO                   = GDK_KEY_Hangul_EO,
    _Hangul_E                    = GDK_KEY_Hangul_E,
    _Hangul_YEO                  = GDK_KEY_Hangul_YEO,
    _Hangul_YE                   = GDK_KEY_Hangul_YE,
    _Hangul_O                    = GDK_KEY_Hangul_O,
    _Hangul_WA                   = GDK_KEY_Hangul_WA,
    _Hangul_WAE                  = GDK_KEY_Hangul_WAE,
    _Hangul_OE                   = GDK_KEY_Hangul_OE,
    _Hangul_YO                   = GDK_KEY_Hangul_YO,
    _Hangul_U                    = GDK_KEY_Hangul_U,
    _Hangul_WEO                  = GDK_KEY_Hangul_WEO,
    _Hangul_WE                   = GDK_KEY_Hangul_WE,
    _Hangul_WI                   = GDK_KEY_Hangul_WI,
    _Hangul_YU                   = GDK_KEY_Hangul_YU,
    _Hangul_EU                   = GDK_KEY_Hangul_EU,
    _Hangul_YI                   = GDK_KEY_Hangul_YI,
    _Hangul_I                    = GDK_KEY_Hangul_I,
    _Hangul_J_Kiyeog             = GDK_KEY_Hangul_J_Kiyeog,
    _Hangul_J_SsangKiyeog        = GDK_KEY_Hangul_J_SsangKiyeog,
    _Hangul_J_KiyeogSios         = GDK_KEY_Hangul_J_KiyeogSios,
    _Hangul_J_Nieun              = GDK_KEY_Hangul_J_Nieun,
    _Hangul_J_NieunJieuj         = GDK_KEY_Hangul_J_NieunJieuj,
    _Hangul_J_NieunHieuh         = GDK_KEY_Hangul_J_NieunHieuh,
    _Hangul_J_Dikeud             = GDK_KEY_Hangul_J_Dikeud,
    _Hangul_J_Rieul              = GDK_KEY_Hangul_J_Rieul,
    _Hangul_J_RieulKiyeog        = GDK_KEY_Hangul_J_RieulKiyeog,
    _Hangul_J_RieulMieum         = GDK_KEY_Hangul_J_RieulMieum,
    _Hangul_J_RieulPieub         = GDK_KEY_Hangul_J_RieulPieub,
    _Hangul_J_RieulSios          = GDK_KEY_Hangul_J_RieulSios,
    _Hangul_J_RieulTieut         = GDK_KEY_Hangul_J_RieulTieut,
    _Hangul_J_RieulPhieuf        = GDK_KEY_Hangul_J_RieulPhieuf,
    _Hangul_J_RieulHieuh         = GDK_KEY_Hangul_J_RieulHieuh,
    _Hangul_J_Mieum              = GDK_KEY_Hangul_J_Mieum,
    _Hangul_J_Pieub              = GDK_KEY_Hangul_J_Pieub,
    _Hangul_J_PieubSios          = GDK_KEY_Hangul_J_PieubSios,
    _Hangul_J_Sios               = GDK_KEY_Hangul_J_Sios,
    _Hangul_J_SsangSios          = GDK_KEY_Hangul_J_SsangSios,
    _Hangul_J_Ieung              = GDK_KEY_Hangul_J_Ieung,
    _Hangul_J_Jieuj              = GDK_KEY_Hangul_J_Jieuj,
    _Hangul_J_Cieuc              = GDK_KEY_Hangul_J_Cieuc,
    _Hangul_J_Khieuq             = GDK_KEY_Hangul_J_Khieuq,
    _Hangul_J_Tieut              = GDK_KEY_Hangul_J_Tieut,
    _Hangul_J_Phieuf             = GDK_KEY_Hangul_J_Phieuf,
    _Hangul_J_Hieuh              = GDK_KEY_Hangul_J_Hieuh,
    _Hangul_RieulYeorinHieuh     = GDK_KEY_Hangul_RieulYeorinHieuh,
    _Hangul_SunkyeongeumMieum    = GDK_KEY_Hangul_SunkyeongeumMieum,
    _Hangul_SunkyeongeumPieub    = GDK_KEY_Hangul_SunkyeongeumPieub,
    _Hangul_PanSios              = GDK_KEY_Hangul_PanSios,
    _Hangul_KkogjiDalrinIeung    = GDK_KEY_Hangul_KkogjiDalrinIeung,
    _Hangul_SunkyeongeumPhieuf   = GDK_KEY_Hangul_SunkyeongeumPhieuf,
    _Hangul_YeorinHieuh          = GDK_KEY_Hangul_YeorinHieuh,
    _Hangul_AraeA                = GDK_KEY_Hangul_AraeA,
    _Hangul_AraeAE               = GDK_KEY_Hangul_AraeAE,
    _Hangul_J_PanSios            = GDK_KEY_Hangul_J_PanSios,
    _Hangul_J_KkogjiDalrinIeung  = GDK_KEY_Hangul_J_KkogjiDalrinIeung,
    _Hangul_J_YeorinHieuh        = GDK_KEY_Hangul_J_YeorinHieuh,
    _Korean_Won                  = GDK_KEY_Korean_Won,
    _Armenian_ligature_ew        = GDK_KEY_Armenian_ligature_ew,
    _Armenian_full_stop          = GDK_KEY_Armenian_full_stop,
    _Armenian_verjaket           = GDK_KEY_Armenian_verjaket,
    _Armenian_separation_mark    = GDK_KEY_Armenian_separation_mark,
    _Armenian_but                = GDK_KEY_Armenian_but,
    _Armenian_hyphen             = GDK_KEY_Armenian_hyphen,
    _Armenian_yentamna           = GDK_KEY_Armenian_yentamna,
    _Armenian_exclam             = GDK_KEY_Armenian_exclam,
    _Armenian_amanak             = GDK_KEY_Armenian_amanak,
    _Armenian_accent             = GDK_KEY_Armenian_accent,
    _Armenian_shesht             = GDK_KEY_Armenian_shesht,
    _Armenian_question           = GDK_KEY_Armenian_question,
    _Armenian_paruyk             = GDK_KEY_Armenian_paruyk,
    _Armenian_AYB                = GDK_KEY_Armenian_AYB,
    _Armenian_ayb                = GDK_KEY_Armenian_ayb,
    _Armenian_BEN                = GDK_KEY_Armenian_BEN,
    _Armenian_ben                = GDK_KEY_Armenian_ben,
    _Armenian_GIM                = GDK_KEY_Armenian_GIM,
    _Armenian_gim                = GDK_KEY_Armenian_gim,
    _Armenian_DA                 = GDK_KEY_Armenian_DA,
    _Armenian_da                 = GDK_KEY_Armenian_da,
    _Armenian_YECH               = GDK_KEY_Armenian_YECH,
    _Armenian_yech               = GDK_KEY_Armenian_yech,
    _Armenian_ZA                 = GDK_KEY_Armenian_ZA,
    _Armenian_za                 = GDK_KEY_Armenian_za,
    _Armenian_E                  = GDK_KEY_Armenian_E,
    _Armenian_e                  = GDK_KEY_Armenian_e,
    _Armenian_AT                 = GDK_KEY_Armenian_AT,
    _Armenian_at                 = GDK_KEY_Armenian_at,
    _Armenian_TO                 = GDK_KEY_Armenian_TO,
    _Armenian_to                 = GDK_KEY_Armenian_to,
    _Armenian_ZHE                = GDK_KEY_Armenian_ZHE,
    _Armenian_zhe                = GDK_KEY_Armenian_zhe,
    _Armenian_INI                = GDK_KEY_Armenian_INI,
    _Armenian_ini                = GDK_KEY_Armenian_ini,
    _Armenian_LYUN               = GDK_KEY_Armenian_LYUN,
    _Armenian_lyun               = GDK_KEY_Armenian_lyun,
    _Armenian_KHE                = GDK_KEY_Armenian_KHE,
    _Armenian_khe                = GDK_KEY_Armenian_khe,
    _Armenian_TSA                = GDK_KEY_Armenian_TSA,
    _Armenian_tsa                = GDK_KEY_Armenian_tsa,
    _Armenian_KEN                = GDK_KEY_Armenian_KEN,
    _Armenian_ken                = GDK_KEY_Armenian_ken,
    _Armenian_HO                 = GDK_KEY_Armenian_HO,
    _Armenian_ho                 = GDK_KEY_Armenian_ho,
    _Armenian_DZA                = GDK_KEY_Armenian_DZA,
    _Armenian_dza                = GDK_KEY_Armenian_dza,
    _Armenian_GHAT               = GDK_KEY_Armenian_GHAT,
    _Armenian_ghat               = GDK_KEY_Armenian_ghat,
    _Armenian_TCHE               = GDK_KEY_Armenian_TCHE,
    _Armenian_tche               = GDK_KEY_Armenian_tche,
    _Armenian_MEN                = GDK_KEY_Armenian_MEN,
    _Armenian_men                = GDK_KEY_Armenian_men,
    _Armenian_HI                 = GDK_KEY_Armenian_HI,
    _Armenian_hi                 = GDK_KEY_Armenian_hi,
    _Armenian_NU                 = GDK_KEY_Armenian_NU,
    _Armenian_nu                 = GDK_KEY_Armenian_nu,
    _Armenian_SHA                = GDK_KEY_Armenian_SHA,
    _Armenian_sha                = GDK_KEY_Armenian_sha,
    _Armenian_VO                 = GDK_KEY_Armenian_VO,
    _Armenian_vo                 = GDK_KEY_Armenian_vo,
    _Armenian_CHA                = GDK_KEY_Armenian_CHA,
    _Armenian_cha                = GDK_KEY_Armenian_cha,
    _Armenian_PE                 = GDK_KEY_Armenian_PE,
    _Armenian_pe                 = GDK_KEY_Armenian_pe,
    _Armenian_JE                 = GDK_KEY_Armenian_JE,
    _Armenian_je                 = GDK_KEY_Armenian_je,
    _Armenian_RA                 = GDK_KEY_Armenian_RA,
    _Armenian_ra                 = GDK_KEY_Armenian_ra,
    _Armenian_SE                 = GDK_KEY_Armenian_SE,
    _Armenian_se                 = GDK_KEY_Armenian_se,
    _Armenian_VEV                = GDK_KEY_Armenian_VEV,
    _Armenian_vev                = GDK_KEY_Armenian_vev,
    _Armenian_TYUN               = GDK_KEY_Armenian_TYUN,
    _Armenian_tyun               = GDK_KEY_Armenian_tyun,
    _Armenian_RE                 = GDK_KEY_Armenian_RE,
    _Armenian_re                 = GDK_KEY_Armenian_re,
    _Armenian_TSO                = GDK_KEY_Armenian_TSO,
    _Armenian_tso                = GDK_KEY_Armenian_tso,
    _Armenian_VYUN               = GDK_KEY_Armenian_VYUN,
    _Armenian_vyun               = GDK_KEY_Armenian_vyun,
    _Armenian_PYUR               = GDK_KEY_Armenian_PYUR,
    _Armenian_pyur               = GDK_KEY_Armenian_pyur,
    _Armenian_KE                 = GDK_KEY_Armenian_KE,
    _Armenian_ke                 = GDK_KEY_Armenian_ke,
    _Armenian_O                  = GDK_KEY_Armenian_O,
    _Armenian_o                  = GDK_KEY_Armenian_o,
    _Armenian_FE                 = GDK_KEY_Armenian_FE,
    _Armenian_fe                 = GDK_KEY_Armenian_fe,
    _Armenian_apostrophe         = GDK_KEY_Armenian_apostrophe,
    _Georgian_an                 = GDK_KEY_Georgian_an,
    _Georgian_ban                = GDK_KEY_Georgian_ban,
    _Georgian_gan                = GDK_KEY_Georgian_gan,
    _Georgian_don                = GDK_KEY_Georgian_don,
    _Georgian_en                 = GDK_KEY_Georgian_en,
    _Georgian_vin                = GDK_KEY_Georgian_vin,
    _Georgian_zen                = GDK_KEY_Georgian_zen,
    _Georgian_tan                = GDK_KEY_Georgian_tan,
    _Georgian_in                 = GDK_KEY_Georgian_in,
    _Georgian_kan                = GDK_KEY_Georgian_kan,
    _Georgian_las                = GDK_KEY_Georgian_las,
    _Georgian_man                = GDK_KEY_Georgian_man,
    _Georgian_nar                = GDK_KEY_Georgian_nar,
    _Georgian_on                 = GDK_KEY_Georgian_on,
    _Georgian_par                = GDK_KEY_Georgian_par,
    _Georgian_zhar               = GDK_KEY_Georgian_zhar,
    _Georgian_rae                = GDK_KEY_Georgian_rae,
    _Georgian_san                = GDK_KEY_Georgian_san,
    _Georgian_tar                = GDK_KEY_Georgian_tar,
    _Georgian_un                 = GDK_KEY_Georgian_un,
    _Georgian_phar               = GDK_KEY_Georgian_phar,
    _Georgian_khar               = GDK_KEY_Georgian_khar,
    _Georgian_ghan               = GDK_KEY_Georgian_ghan,
    _Georgian_qar                = GDK_KEY_Georgian_qar,
    _Georgian_shin               = GDK_KEY_Georgian_shin,
    _Georgian_chin               = GDK_KEY_Georgian_chin,
    _Georgian_can                = GDK_KEY_Georgian_can,
    _Georgian_jil                = GDK_KEY_Georgian_jil,
    _Georgian_cil                = GDK_KEY_Georgian_cil,
    _Georgian_char               = GDK_KEY_Georgian_char,
    _Georgian_xan                = GDK_KEY_Georgian_xan,
    _Georgian_jhan               = GDK_KEY_Georgian_jhan,
    _Georgian_hae                = GDK_KEY_Georgian_hae,
    _Georgian_he                 = GDK_KEY_Georgian_he,
    _Georgian_hie                = GDK_KEY_Georgian_hie,
    _Georgian_we                 = GDK_KEY_Georgian_we,
    _Georgian_har                = GDK_KEY_Georgian_har,
    _Georgian_hoe                = GDK_KEY_Georgian_hoe,
    _Georgian_fi                 = GDK_KEY_Georgian_fi,
    _Xabovedot                   = GDK_KEY_Xabovedot,
    _Ibreve                      = GDK_KEY_Ibreve,
    _Zstroke                     = GDK_KEY_Zstroke,
    _Gcaron                      = GDK_KEY_Gcaron,
    _Ocaron                      = GDK_KEY_Ocaron,
    _Obarred                     = GDK_KEY_Obarred,
    _xabovedot                   = GDK_KEY_xabovedot,
    _ibreve                      = GDK_KEY_ibreve,
    _zstroke                     = GDK_KEY_zstroke,
    _gcaron                      = GDK_KEY_gcaron,
    _ocaron                      = GDK_KEY_ocaron,
    _obarred                     = GDK_KEY_obarred,
    _SCHWA                       = GDK_KEY_SCHWA,
    _schwa                       = GDK_KEY_schwa,
    _Lbelowdot                   = GDK_KEY_Lbelowdot,
    _lbelowdot                   = GDK_KEY_lbelowdot,
    _Abelowdot                   = GDK_KEY_Abelowdot,
    _abelowdot                   = GDK_KEY_abelowdot,
    _Ahook                       = GDK_KEY_Ahook,
    _ahook                       = GDK_KEY_ahook,
    _Acircumflexacute            = GDK_KEY_Acircumflexacute,
    _acircumflexacute            = GDK_KEY_acircumflexacute,
    _Acircumflexgrave            = GDK_KEY_Acircumflexgrave,
    _acircumflexgrave            = GDK_KEY_acircumflexgrave,
    _Acircumflexhook             = GDK_KEY_Acircumflexhook,
    _acircumflexhook             = GDK_KEY_acircumflexhook,
    _Acircumflextilde            = GDK_KEY_Acircumflextilde,
    _acircumflextilde            = GDK_KEY_acircumflextilde,
    _Acircumflexbelowdot         = GDK_KEY_Acircumflexbelowdot,
    _acircumflexbelowdot         = GDK_KEY_acircumflexbelowdot,
    _Abreveacute                 = GDK_KEY_Abreveacute,
    _abreveacute                 = GDK_KEY_abreveacute,
    _Abrevegrave                 = GDK_KEY_Abrevegrave,
    _abrevegrave                 = GDK_KEY_abrevegrave,
    _Abrevehook                  = GDK_KEY_Abrevehook,
    _abrevehook                  = GDK_KEY_abrevehook,
    _Abrevetilde                 = GDK_KEY_Abrevetilde,
    _abrevetilde                 = GDK_KEY_abrevetilde,
    _Abrevebelowdot              = GDK_KEY_Abrevebelowdot,
    _abrevebelowdot              = GDK_KEY_abrevebelowdot,
    _Ebelowdot                   = GDK_KEY_Ebelowdot,
    _ebelowdot                   = GDK_KEY_ebelowdot,
    _Ehook                       = GDK_KEY_Ehook,
    _ehook                       = GDK_KEY_ehook,
    _Etilde                      = GDK_KEY_Etilde,
    _etilde                      = GDK_KEY_etilde,
    _Ecircumflexacute            = GDK_KEY_Ecircumflexacute,
    _ecircumflexacute            = GDK_KEY_ecircumflexacute,
    _Ecircumflexgrave            = GDK_KEY_Ecircumflexgrave,
    _ecircumflexgrave            = GDK_KEY_ecircumflexgrave,
    _Ecircumflexhook             = GDK_KEY_Ecircumflexhook,
    _ecircumflexhook             = GDK_KEY_ecircumflexhook,
    _Ecircumflextilde            = GDK_KEY_Ecircumflextilde,
    _ecircumflextilde            = GDK_KEY_ecircumflextilde,
    _Ecircumflexbelowdot         = GDK_KEY_Ecircumflexbelowdot,
    _ecircumflexbelowdot         = GDK_KEY_ecircumflexbelowdot,
    _Ihook                       = GDK_KEY_Ihook,
    _ihook                       = GDK_KEY_ihook,
    _Ibelowdot                   = GDK_KEY_Ibelowdot,
    _ibelowdot                   = GDK_KEY_ibelowdot,
    _Obelowdot                   = GDK_KEY_Obelowdot,
    _obelowdot                   = GDK_KEY_obelowdot,
    _Ohook                       = GDK_KEY_Ohook,
    _ohook                       = GDK_KEY_ohook,
    _Ocircumflexacute            = GDK_KEY_Ocircumflexacute,
    _ocircumflexacute            = GDK_KEY_ocircumflexacute,
    _Ocircumflexgrave            = GDK_KEY_Ocircumflexgrave,
    _ocircumflexgrave            = GDK_KEY_ocircumflexgrave,
    _Ocircumflexhook             = GDK_KEY_Ocircumflexhook,
    _ocircumflexhook             = GDK_KEY_ocircumflexhook,
    _Ocircumflextilde            = GDK_KEY_Ocircumflextilde,
    _ocircumflextilde            = GDK_KEY_ocircumflextilde,
    _Ocircumflexbelowdot         = GDK_KEY_Ocircumflexbelowdot,
    _ocircumflexbelowdot         = GDK_KEY_ocircumflexbelowdot,
    _Ohornacute                  = GDK_KEY_Ohornacute,
    _ohornacute                  = GDK_KEY_ohornacute,
    _Ohorngrave                  = GDK_KEY_Ohorngrave,
    _ohorngrave                  = GDK_KEY_ohorngrave,
    _Ohornhook                   = GDK_KEY_Ohornhook,
    _ohornhook                   = GDK_KEY_ohornhook,
    _Ohorntilde                  = GDK_KEY_Ohorntilde,
    _ohorntilde                  = GDK_KEY_ohorntilde,
    _Ohornbelowdot               = GDK_KEY_Ohornbelowdot,
    _ohornbelowdot               = GDK_KEY_ohornbelowdot,
    _Ubelowdot                   = GDK_KEY_Ubelowdot,
    _ubelowdot                   = GDK_KEY_ubelowdot,
    _Uhook                       = GDK_KEY_Uhook,
    _uhook                       = GDK_KEY_uhook,
    _Uhornacute                  = GDK_KEY_Uhornacute,
    _uhornacute                  = GDK_KEY_uhornacute,
    _Uhorngrave                  = GDK_KEY_Uhorngrave,
    _uhorngrave                  = GDK_KEY_uhorngrave,
    _Uhornhook                   = GDK_KEY_Uhornhook,
    _uhornhook                   = GDK_KEY_uhornhook,
    _Uhorntilde                  = GDK_KEY_Uhorntilde,
    _uhorntilde                  = GDK_KEY_uhorntilde,
    _Uhornbelowdot               = GDK_KEY_Uhornbelowdot,
    _uhornbelowdot               = GDK_KEY_uhornbelowdot,
    _Ybelowdot                   = GDK_KEY_Ybelowdot,
    _ybelowdot                   = GDK_KEY_ybelowdot,
    _Yhook                       = GDK_KEY_Yhook,
    _yhook                       = GDK_KEY_yhook,
    _Ytilde                      = GDK_KEY_Ytilde,
    _ytilde                      = GDK_KEY_ytilde,
    _Ohorn                       = GDK_KEY_Ohorn,
    _ohorn                       = GDK_KEY_ohorn,
    _Uhorn                       = GDK_KEY_Uhorn,
    _uhorn                       = GDK_KEY_uhorn,
    _EcuSign                     = GDK_KEY_EcuSign,
    _ColonSign                   = GDK_KEY_ColonSign,
    _CruzeiroSign                = GDK_KEY_CruzeiroSign,
    _FFrancSign                  = GDK_KEY_FFrancSign,
    _LiraSign                    = GDK_KEY_LiraSign,
    _MillSign                    = GDK_KEY_MillSign,
    _NairaSign                   = GDK_KEY_NairaSign,
    _PesetaSign                  = GDK_KEY_PesetaSign,
    _RupeeSign                   = GDK_KEY_RupeeSign,
    _WonSign                     = GDK_KEY_WonSign,
    _NewSheqelSign               = GDK_KEY_NewSheqelSign,
    _DongSign                    = GDK_KEY_DongSign,
    _EuroSign                    = GDK_KEY_EuroSign,
    _zerosuperior                = GDK_KEY_zerosuperior,
    _foursuperior                = GDK_KEY_foursuperior,
    _fivesuperior                = GDK_KEY_fivesuperior,
    _sixsuperior                 = GDK_KEY_sixsuperior,
    _sevensuperior               = GDK_KEY_sevensuperior,
    _eightsuperior               = GDK_KEY_eightsuperior,
    _ninesuperior                = GDK_KEY_ninesuperior,
    _zerosubscript               = GDK_KEY_zerosubscript,
    _onesubscript                = GDK_KEY_onesubscript,
    _twosubscript                = GDK_KEY_twosubscript,
    _threesubscript              = GDK_KEY_threesubscript,
    _foursubscript               = GDK_KEY_foursubscript,
    _fivesubscript               = GDK_KEY_fivesubscript,
    _sixsubscript                = GDK_KEY_sixsubscript,
    _sevensubscript              = GDK_KEY_sevensubscript,
    _eightsubscript              = GDK_KEY_eightsubscript,
    _ninesubscript               = GDK_KEY_ninesubscript,
    _partdifferential            = GDK_KEY_partdifferential,
    _emptyset                    = GDK_KEY_emptyset,
    _elementof                   = GDK_KEY_elementof,
    _notelementof                = GDK_KEY_notelementof,
    _containsas                  = GDK_KEY_containsas,
    _squareroot                  = GDK_KEY_squareroot,
    _cuberoot                    = GDK_KEY_cuberoot,
    _fourthroot                  = GDK_KEY_fourthroot,
    _dintegral                   = GDK_KEY_dintegral,
    _tintegral                   = GDK_KEY_tintegral,
    _because                     = GDK_KEY_because,
    _approxeq                    = GDK_KEY_approxeq,
    _notapproxeq                 = GDK_KEY_notapproxeq,
    _notidentical                = GDK_KEY_notidentical,
    _stricteq                    = GDK_KEY_stricteq,
    _braille_dot_1               = GDK_KEY_braille_dot_1,
    _braille_dot_2               = GDK_KEY_braille_dot_2,
    _braille_dot_3               = GDK_KEY_braille_dot_3,
    _braille_dot_4               = GDK_KEY_braille_dot_4,
    _braille_dot_5               = GDK_KEY_braille_dot_5,
    _braille_dot_6               = GDK_KEY_braille_dot_6,
    _braille_dot_7               = GDK_KEY_braille_dot_7,
    _braille_dot_8               = GDK_KEY_braille_dot_8,
    _braille_dot_9               = GDK_KEY_braille_dot_9,
    _braille_dot_10              = GDK_KEY_braille_dot_10,
    _braille_blank               = GDK_KEY_braille_blank,
    _braille_dots_1              = GDK_KEY_braille_dots_1,
    _braille_dots_2              = GDK_KEY_braille_dots_2,
    _braille_dots_12             = GDK_KEY_braille_dots_12,
    _braille_dots_3              = GDK_KEY_braille_dots_3,
    _braille_dots_13             = GDK_KEY_braille_dots_13,
    _braille_dots_23             = GDK_KEY_braille_dots_23,
    _braille_dots_123            = GDK_KEY_braille_dots_123,
    _braille_dots_4              = GDK_KEY_braille_dots_4,
    _braille_dots_14             = GDK_KEY_braille_dots_14,
    _braille_dots_24             = GDK_KEY_braille_dots_24,
    _braille_dots_124            = GDK_KEY_braille_dots_124,
    _braille_dots_34             = GDK_KEY_braille_dots_34,
    _braille_dots_134            = GDK_KEY_braille_dots_134,
    _braille_dots_234            = GDK_KEY_braille_dots_234,
    _braille_dots_1234           = GDK_KEY_braille_dots_1234,
    _braille_dots_5              = GDK_KEY_braille_dots_5,
    _braille_dots_15             = GDK_KEY_braille_dots_15,
    _braille_dots_25             = GDK_KEY_braille_dots_25,
    _braille_dots_125            = GDK_KEY_braille_dots_125,
    _braille_dots_35             = GDK_KEY_braille_dots_35,
    _braille_dots_135            = GDK_KEY_braille_dots_135,
    _braille_dots_235            = GDK_KEY_braille_dots_235,
    _braille_dots_1235           = GDK_KEY_braille_dots_1235,
    _braille_dots_45             = GDK_KEY_braille_dots_45,
    _braille_dots_145            = GDK_KEY_braille_dots_145,
    _braille_dots_245            = GDK_KEY_braille_dots_245,
    _braille_dots_1245           = GDK_KEY_braille_dots_1245,
    _braille_dots_345            = GDK_KEY_braille_dots_345,
    _braille_dots_1345           = GDK_KEY_braille_dots_1345,
    _braille_dots_2345           = GDK_KEY_braille_dots_2345,
    _braille_dots_12345          = GDK_KEY_braille_dots_12345,
    _braille_dots_6              = GDK_KEY_braille_dots_6,
    _braille_dots_16             = GDK_KEY_braille_dots_16,
    _braille_dots_26             = GDK_KEY_braille_dots_26,
    _braille_dots_126            = GDK_KEY_braille_dots_126,
    _braille_dots_36             = GDK_KEY_braille_dots_36,
    _braille_dots_136            = GDK_KEY_braille_dots_136,
    _braille_dots_236            = GDK_KEY_braille_dots_236,
    _braille_dots_1236           = GDK_KEY_braille_dots_1236,
    _braille_dots_46             = GDK_KEY_braille_dots_46,
    _braille_dots_146            = GDK_KEY_braille_dots_146,
    _braille_dots_246            = GDK_KEY_braille_dots_246,
    _braille_dots_1246           = GDK_KEY_braille_dots_1246,
    _braille_dots_346            = GDK_KEY_braille_dots_346,
    _braille_dots_1346           = GDK_KEY_braille_dots_1346,
    _braille_dots_2346           = GDK_KEY_braille_dots_2346,
    _braille_dots_12346          = GDK_KEY_braille_dots_12346,
    _braille_dots_56             = GDK_KEY_braille_dots_56,
    _braille_dots_156            = GDK_KEY_braille_dots_156,
    _braille_dots_256            = GDK_KEY_braille_dots_256,
    _braille_dots_1256           = GDK_KEY_braille_dots_1256,
    _braille_dots_356            = GDK_KEY_braille_dots_356,
    _braille_dots_1356           = GDK_KEY_braille_dots_1356,
    _braille_dots_2356           = GDK_KEY_braille_dots_2356,
    _braille_dots_12356          = GDK_KEY_braille_dots_12356,
    _braille_dots_456            = GDK_KEY_braille_dots_456,
    _braille_dots_1456           = GDK_KEY_braille_dots_1456,
    _braille_dots_2456           = GDK_KEY_braille_dots_2456,
    _braille_dots_12456          = GDK_KEY_braille_dots_12456,
    _braille_dots_3456           = GDK_KEY_braille_dots_3456,
    _braille_dots_13456          = GDK_KEY_braille_dots_13456,
    _braille_dots_23456          = GDK_KEY_braille_dots_23456,
    _braille_dots_123456         = GDK_KEY_braille_dots_123456,
    _braille_dots_7              = GDK_KEY_braille_dots_7,
    _braille_dots_17             = GDK_KEY_braille_dots_17,
    _braille_dots_27             = GDK_KEY_braille_dots_27,
    _braille_dots_127            = GDK_KEY_braille_dots_127,
    _braille_dots_37             = GDK_KEY_braille_dots_37,
    _braille_dots_137            = GDK_KEY_braille_dots_137,
    _braille_dots_237            = GDK_KEY_braille_dots_237,
    _braille_dots_1237           = GDK_KEY_braille_dots_1237,
    _braille_dots_47             = GDK_KEY_braille_dots_47,
    _braille_dots_147            = GDK_KEY_braille_dots_147,
    _braille_dots_247            = GDK_KEY_braille_dots_247,
    _braille_dots_1247           = GDK_KEY_braille_dots_1247,
    _braille_dots_347            = GDK_KEY_braille_dots_347,
    _braille_dots_1347           = GDK_KEY_braille_dots_1347,
    _braille_dots_2347           = GDK_KEY_braille_dots_2347,
    _braille_dots_12347          = GDK_KEY_braille_dots_12347,
    _braille_dots_57             = GDK_KEY_braille_dots_57,
    _braille_dots_157            = GDK_KEY_braille_dots_157,
    _braille_dots_257            = GDK_KEY_braille_dots_257,
    _braille_dots_1257           = GDK_KEY_braille_dots_1257,
    _braille_dots_357            = GDK_KEY_braille_dots_357,
    _braille_dots_1357           = GDK_KEY_braille_dots_1357,
    _braille_dots_2357           = GDK_KEY_braille_dots_2357,
    _braille_dots_12357          = GDK_KEY_braille_dots_12357,
    _braille_dots_457            = GDK_KEY_braille_dots_457,
    _braille_dots_1457           = GDK_KEY_braille_dots_1457,
    _braille_dots_2457           = GDK_KEY_braille_dots_2457,
    _braille_dots_12457          = GDK_KEY_braille_dots_12457,
    _braille_dots_3457           = GDK_KEY_braille_dots_3457,
    _braille_dots_13457          = GDK_KEY_braille_dots_13457,
    _braille_dots_23457          = GDK_KEY_braille_dots_23457,
    _braille_dots_123457         = GDK_KEY_braille_dots_123457,
    _braille_dots_67             = GDK_KEY_braille_dots_67,
    _braille_dots_167            = GDK_KEY_braille_dots_167,
    _braille_dots_267            = GDK_KEY_braille_dots_267,
    _braille_dots_1267           = GDK_KEY_braille_dots_1267,
    _braille_dots_367            = GDK_KEY_braille_dots_367,
    _braille_dots_1367           = GDK_KEY_braille_dots_1367,
    _braille_dots_2367           = GDK_KEY_braille_dots_2367,
    _braille_dots_12367          = GDK_KEY_braille_dots_12367,
    _braille_dots_467            = GDK_KEY_braille_dots_467,
    _braille_dots_1467           = GDK_KEY_braille_dots_1467,
    _braille_dots_2467           = GDK_KEY_braille_dots_2467,
    _braille_dots_12467          = GDK_KEY_braille_dots_12467,
    _braille_dots_3467           = GDK_KEY_braille_dots_3467,
    _braille_dots_13467          = GDK_KEY_braille_dots_13467,
    _braille_dots_23467          = GDK_KEY_braille_dots_23467,
    _braille_dots_123467         = GDK_KEY_braille_dots_123467,
    _braille_dots_567            = GDK_KEY_braille_dots_567,
    _braille_dots_1567           = GDK_KEY_braille_dots_1567,
    _braille_dots_2567           = GDK_KEY_braille_dots_2567,
    _braille_dots_12567          = GDK_KEY_braille_dots_12567,
    _braille_dots_3567           = GDK_KEY_braille_dots_3567,
    _braille_dots_13567          = GDK_KEY_braille_dots_13567,
    _braille_dots_23567          = GDK_KEY_braille_dots_23567,
    _braille_dots_123567         = GDK_KEY_braille_dots_123567,
    _braille_dots_4567           = GDK_KEY_braille_dots_4567,
    _braille_dots_14567          = GDK_KEY_braille_dots_14567,
    _braille_dots_24567          = GDK_KEY_braille_dots_24567,
    _braille_dots_124567         = GDK_KEY_braille_dots_124567,
    _braille_dots_34567          = GDK_KEY_braille_dots_34567,
    _braille_dots_134567         = GDK_KEY_braille_dots_134567,
    _braille_dots_234567         = GDK_KEY_braille_dots_234567,
    _braille_dots_1234567        = GDK_KEY_braille_dots_1234567,
    _braille_dots_8              = GDK_KEY_braille_dots_8,
    _braille_dots_18             = GDK_KEY_braille_dots_18,
    _braille_dots_28             = GDK_KEY_braille_dots_28,
    _braille_dots_128            = GDK_KEY_braille_dots_128,
    _braille_dots_38             = GDK_KEY_braille_dots_38,
    _braille_dots_138            = GDK_KEY_braille_dots_138,
    _braille_dots_238            = GDK_KEY_braille_dots_238,
    _braille_dots_1238           = GDK_KEY_braille_dots_1238,
    _braille_dots_48             = GDK_KEY_braille_dots_48,
    _braille_dots_148            = GDK_KEY_braille_dots_148,
    _braille_dots_248            = GDK_KEY_braille_dots_248,
    _braille_dots_1248           = GDK_KEY_braille_dots_1248,
    _braille_dots_348            = GDK_KEY_braille_dots_348,
    _braille_dots_1348           = GDK_KEY_braille_dots_1348,
    _braille_dots_2348           = GDK_KEY_braille_dots_2348,
    _braille_dots_12348          = GDK_KEY_braille_dots_12348,
    _braille_dots_58             = GDK_KEY_braille_dots_58,
    _braille_dots_158            = GDK_KEY_braille_dots_158,
    _braille_dots_258            = GDK_KEY_braille_dots_258,
    _braille_dots_1258           = GDK_KEY_braille_dots_1258,
    _braille_dots_358            = GDK_KEY_braille_dots_358,
    _braille_dots_1358           = GDK_KEY_braille_dots_1358,
    _braille_dots_2358           = GDK_KEY_braille_dots_2358,
    _braille_dots_12358          = GDK_KEY_braille_dots_12358,
    _braille_dots_458            = GDK_KEY_braille_dots_458,
    _braille_dots_1458           = GDK_KEY_braille_dots_1458,
    _braille_dots_2458           = GDK_KEY_braille_dots_2458,
    _braille_dots_12458          = GDK_KEY_braille_dots_12458,
    _braille_dots_3458           = GDK_KEY_braille_dots_3458,
    _braille_dots_13458          = GDK_KEY_braille_dots_13458,
    _braille_dots_23458          = GDK_KEY_braille_dots_23458,
    _braille_dots_123458         = GDK_KEY_braille_dots_123458,
    _braille_dots_68             = GDK_KEY_braille_dots_68,
    _braille_dots_168            = GDK_KEY_braille_dots_168,
    _braille_dots_268            = GDK_KEY_braille_dots_268,
    _braille_dots_1268           = GDK_KEY_braille_dots_1268,
    _braille_dots_368            = GDK_KEY_braille_dots_368,
    _braille_dots_1368           = GDK_KEY_braille_dots_1368,
    _braille_dots_2368           = GDK_KEY_braille_dots_2368,
    _braille_dots_12368          = GDK_KEY_braille_dots_12368,
    _braille_dots_468            = GDK_KEY_braille_dots_468,
    _braille_dots_1468           = GDK_KEY_braille_dots_1468,
    _braille_dots_2468           = GDK_KEY_braille_dots_2468,
    _braille_dots_12468          = GDK_KEY_braille_dots_12468,
    _braille_dots_3468           = GDK_KEY_braille_dots_3468,
    _braille_dots_13468          = GDK_KEY_braille_dots_13468,
    _braille_dots_23468          = GDK_KEY_braille_dots_23468,
    _braille_dots_123468         = GDK_KEY_braille_dots_123468,
    _braille_dots_568            = GDK_KEY_braille_dots_568,
    _braille_dots_1568           = GDK_KEY_braille_dots_1568,
    _braille_dots_2568           = GDK_KEY_braille_dots_2568,
    _braille_dots_12568          = GDK_KEY_braille_dots_12568,
    _braille_dots_3568           = GDK_KEY_braille_dots_3568,
    _braille_dots_13568          = GDK_KEY_braille_dots_13568,
    _braille_dots_23568          = GDK_KEY_braille_dots_23568,
    _braille_dots_123568         = GDK_KEY_braille_dots_123568,
    _braille_dots_4568           = GDK_KEY_braille_dots_4568,
    _braille_dots_14568          = GDK_KEY_braille_dots_14568,
    _braille_dots_24568          = GDK_KEY_braille_dots_24568,
    _braille_dots_124568         = GDK_KEY_braille_dots_124568,
    _braille_dots_34568          = GDK_KEY_braille_dots_34568,
    _braille_dots_134568         = GDK_KEY_braille_dots_134568,
    _braille_dots_234568         = GDK_KEY_braille_dots_234568,
    _braille_dots_1234568        = GDK_KEY_braille_dots_1234568,
    _braille_dots_78             = GDK_KEY_braille_dots_78,
    _braille_dots_178            = GDK_KEY_braille_dots_178,
    _braille_dots_278            = GDK_KEY_braille_dots_278,
    _braille_dots_1278           = GDK_KEY_braille_dots_1278,
    _braille_dots_378            = GDK_KEY_braille_dots_378,
    _braille_dots_1378           = GDK_KEY_braille_dots_1378,
    _braille_dots_2378           = GDK_KEY_braille_dots_2378,
    _braille_dots_12378          = GDK_KEY_braille_dots_12378,
    _braille_dots_478            = GDK_KEY_braille_dots_478,
    _braille_dots_1478           = GDK_KEY_braille_dots_1478,
    _braille_dots_2478           = GDK_KEY_braille_dots_2478,
    _braille_dots_12478          = GDK_KEY_braille_dots_12478,
    _braille_dots_3478           = GDK_KEY_braille_dots_3478,
    _braille_dots_13478          = GDK_KEY_braille_dots_13478,
    _braille_dots_23478          = GDK_KEY_braille_dots_23478,
    _braille_dots_123478         = GDK_KEY_braille_dots_123478,
    _braille_dots_578            = GDK_KEY_braille_dots_578,
    _braille_dots_1578           = GDK_KEY_braille_dots_1578,
    _braille_dots_2578           = GDK_KEY_braille_dots_2578,
    _braille_dots_12578          = GDK_KEY_braille_dots_12578,
    _braille_dots_3578           = GDK_KEY_braille_dots_3578,
    _braille_dots_13578          = GDK_KEY_braille_dots_13578,
    _braille_dots_23578          = GDK_KEY_braille_dots_23578,
    _braille_dots_123578         = GDK_KEY_braille_dots_123578,
    _braille_dots_4578           = GDK_KEY_braille_dots_4578,
    _braille_dots_14578          = GDK_KEY_braille_dots_14578,
    _braille_dots_24578          = GDK_KEY_braille_dots_24578,
    _braille_dots_124578         = GDK_KEY_braille_dots_124578,
    _braille_dots_34578          = GDK_KEY_braille_dots_34578,
    _braille_dots_134578         = GDK_KEY_braille_dots_134578,
    _braille_dots_234578         = GDK_KEY_braille_dots_234578,
    _braille_dots_1234578        = GDK_KEY_braille_dots_1234578,
    _braille_dots_678            = GDK_KEY_braille_dots_678,
    _braille_dots_1678           = GDK_KEY_braille_dots_1678,
    _braille_dots_2678           = GDK_KEY_braille_dots_2678,
    _braille_dots_12678          = GDK_KEY_braille_dots_12678,
    _braille_dots_3678           = GDK_KEY_braille_dots_3678,
    _braille_dots_13678          = GDK_KEY_braille_dots_13678,
    _braille_dots_23678          = GDK_KEY_braille_dots_23678,
    _braille_dots_123678         = GDK_KEY_braille_dots_123678,
    _braille_dots_4678           = GDK_KEY_braille_dots_4678,
    _braille_dots_14678          = GDK_KEY_braille_dots_14678,
    _braille_dots_24678          = GDK_KEY_braille_dots_24678,
    _braille_dots_124678         = GDK_KEY_braille_dots_124678,
    _braille_dots_34678          = GDK_KEY_braille_dots_34678,
    _braille_dots_134678         = GDK_KEY_braille_dots_134678,
    _braille_dots_234678         = GDK_KEY_braille_dots_234678,
    _braille_dots_1234678        = GDK_KEY_braille_dots_1234678,
    _braille_dots_5678           = GDK_KEY_braille_dots_5678,
    _braille_dots_15678          = GDK_KEY_braille_dots_15678,
    _braille_dots_25678          = GDK_KEY_braille_dots_25678,
    _braille_dots_125678         = GDK_KEY_braille_dots_125678,
    _braille_dots_35678          = GDK_KEY_braille_dots_35678,
    _braille_dots_135678         = GDK_KEY_braille_dots_135678,
    _braille_dots_235678         = GDK_KEY_braille_dots_235678,
    _braille_dots_1235678        = GDK_KEY_braille_dots_1235678,
    _braille_dots_45678          = GDK_KEY_braille_dots_45678,
    _braille_dots_145678         = GDK_KEY_braille_dots_145678,
    _braille_dots_245678         = GDK_KEY_braille_dots_245678,
    _braille_dots_1245678        = GDK_KEY_braille_dots_1245678,
    _braille_dots_345678         = GDK_KEY_braille_dots_345678,
    _braille_dots_1345678        = GDK_KEY_braille_dots_1345678,
    _braille_dots_2345678        = GDK_KEY_braille_dots_2345678,
    _braille_dots_12345678       = GDK_KEY_braille_dots_12345678,
    _ModeLock                    = GDK_KEY_ModeLock,
    _MonBrightnessUp             = GDK_KEY_MonBrightnessUp,
    _MonBrightnessDown           = GDK_KEY_MonBrightnessDown,
    _KbdLightOnOff               = GDK_KEY_KbdLightOnOff,
    _KbdBrightnessUp             = GDK_KEY_KbdBrightnessUp,
    _KbdBrightnessDown           = GDK_KEY_KbdBrightnessDown,
    _Standby                     = GDK_KEY_Standby,
    _AudioLowerVolume            = GDK_KEY_AudioLowerVolume,
    _AudioMute                   = GDK_KEY_AudioMute,
    _AudioRaiseVolume            = GDK_KEY_AudioRaiseVolume,
    _AudioPlay                   = GDK_KEY_AudioPlay,
    _AudioStop                   = GDK_KEY_AudioStop,
    _AudioPrev                   = GDK_KEY_AudioPrev,
    _AudioNext                   = GDK_KEY_AudioNext,
    _HomePage                    = GDK_KEY_HomePage,
    _Mail                        = GDK_KEY_Mail,
    _Start                       = GDK_KEY_Start,
    _Search                      = GDK_KEY_Search,
    _AudioRecord                 = GDK_KEY_AudioRecord,
    _Calculator                  = GDK_KEY_Calculator,
    _Memo                        = GDK_KEY_Memo,
    _ToDoList                    = GDK_KEY_ToDoList,
    _Calendar                    = GDK_KEY_Calendar,
    _PowerDown                   = GDK_KEY_PowerDown,
    _ContrastAdjust              = GDK_KEY_ContrastAdjust,
    _RockerUp                    = GDK_KEY_RockerUp,
    _RockerDown                  = GDK_KEY_RockerDown,
    _RockerEnter                 = GDK_KEY_RockerEnter,
    _Back                        = GDK_KEY_Back,
    _Forward                     = GDK_KEY_Forward,
    _Stop                        = GDK_KEY_Stop,
    _Refresh                     = GDK_KEY_Refresh,
    _PowerOff                    = GDK_KEY_PowerOff,
    _WakeUp                      = GDK_KEY_WakeUp,
    _Eject                       = GDK_KEY_Eject,
    _ScreenSaver                 = GDK_KEY_ScreenSaver,
    _WWW                         = GDK_KEY_WWW,
    _Sleep                       = GDK_KEY_Sleep,
    _Favorites                   = GDK_KEY_Favorites,
    _AudioPause                  = GDK_KEY_AudioPause,
    _AudioMedia                  = GDK_KEY_AudioMedia,
    _MyComputer                  = GDK_KEY_MyComputer,
    _VendorHome                  = GDK_KEY_VendorHome,
    _LightBulb                   = GDK_KEY_LightBulb,
    _Shop                        = GDK_KEY_Shop,
    _History                     = GDK_KEY_History,
    _OpenURL                     = GDK_KEY_OpenURL,
    _AddFavorite                 = GDK_KEY_AddFavorite,
    _HotLinks                    = GDK_KEY_HotLinks,
    _BrightnessAdjust            = GDK_KEY_BrightnessAdjust,
    _Finance                     = GDK_KEY_Finance,
    _Community                   = GDK_KEY_Community,
    _AudioRewind                 = GDK_KEY_AudioRewind,
    _BackForward                 = GDK_KEY_BackForward,
    _Launch0                     = GDK_KEY_Launch0,
    _Launch1                     = GDK_KEY_Launch1,
    _Launch2                     = GDK_KEY_Launch2,
    _Launch3                     = GDK_KEY_Launch3,
    _Launch4                     = GDK_KEY_Launch4,
    _Launch5                     = GDK_KEY_Launch5,
    _Launch6                     = GDK_KEY_Launch6,
    _Launch7                     = GDK_KEY_Launch7,
    _Launch8                     = GDK_KEY_Launch8,
    _Launch9                     = GDK_KEY_Launch9,
    _LaunchA                     = GDK_KEY_LaunchA,
    _LaunchB                     = GDK_KEY_LaunchB,
    _LaunchC                     = GDK_KEY_LaunchC,
    _LaunchD                     = GDK_KEY_LaunchD,
    _LaunchE                     = GDK_KEY_LaunchE,
    _LaunchF                     = GDK_KEY_LaunchF,
    _ApplicationLeft             = GDK_KEY_ApplicationLeft,
    _ApplicationRight            = GDK_KEY_ApplicationRight,
    _Book                        = GDK_KEY_Book,
    _CD                          = GDK_KEY_CD,
    _WindowClear                 = GDK_KEY_WindowClear,
    _Close                       = GDK_KEY_Close,
    _Copy                        = GDK_KEY_Copy,
    _Cut                         = GDK_KEY_Cut,
    _Display                     = GDK_KEY_Display,
    _DOS                         = GDK_KEY_DOS,
    _Documents                   = GDK_KEY_Documents,
    _Excel                       = GDK_KEY_Excel,
    _Explorer                    = GDK_KEY_Explorer,
    _Game                        = GDK_KEY_Game,
    _Go                          = GDK_KEY_Go,
    _iTouch                      = GDK_KEY_iTouch,
    _LogOff                      = GDK_KEY_LogOff,
    _Market                      = GDK_KEY_Market,
    _Meeting                     = GDK_KEY_Meeting,
    _MenuKB                      = GDK_KEY_MenuKB,
    _MenuPB                      = GDK_KEY_MenuPB,
    _MySites                     = GDK_KEY_MySites,
    _New                         = GDK_KEY_New,
    _News                        = GDK_KEY_News,
    _OfficeHome                  = GDK_KEY_OfficeHome,
    _Open                        = GDK_KEY_Open,
    _Option                      = GDK_KEY_Option,
    _Paste                       = GDK_KEY_Paste,
    _Phone                       = GDK_KEY_Phone,
    _Reply                       = GDK_KEY_Reply,
    _Reload                      = GDK_KEY_Reload,
    _RotateWindows               = GDK_KEY_RotateWindows,
    _RotationPB                  = GDK_KEY_RotationPB,
    _RotationKB                  = GDK_KEY_RotationKB,
    _Save                        = GDK_KEY_Save,
    _ScrollUp                    = GDK_KEY_ScrollUp,
    _ScrollDown                  = GDK_KEY_ScrollDown,
    _ScrollClick                 = GDK_KEY_ScrollClick,
    _Send                        = GDK_KEY_Send,
    _Spell                       = GDK_KEY_Spell,
    _SplitScreen                 = GDK_KEY_SplitScreen,
    _Support                     = GDK_KEY_Support,
    _TaskPane                    = GDK_KEY_TaskPane,
    _Terminal                    = GDK_KEY_Terminal,
    _Tools                       = GDK_KEY_Tools,
    _Travel                      = GDK_KEY_Travel,
    _UserPB                      = GDK_KEY_UserPB,
    _User1KB                     = GDK_KEY_User1KB,
    _User2KB                     = GDK_KEY_User2KB,
    _Video                       = GDK_KEY_Video,
    _WheelButton                 = GDK_KEY_WheelButton,
    _Word                        = GDK_KEY_Word,
    _Xfer                        = GDK_KEY_Xfer,
    _ZoomIn                      = GDK_KEY_ZoomIn,
    _ZoomOut                     = GDK_KEY_ZoomOut,
    _Away                        = GDK_KEY_Away,
    _Messenger                   = GDK_KEY_Messenger,
    _WebCam                      = GDK_KEY_WebCam,
    _MailForward                 = GDK_KEY_MailForward,
    _Pictures                    = GDK_KEY_Pictures,
    _Music                       = GDK_KEY_Music,
    _Battery                     = GDK_KEY_Battery,
    _Bluetooth                   = GDK_KEY_Bluetooth,
    _WLAN                        = GDK_KEY_WLAN,
    _UWB                         = GDK_KEY_UWB,
    _AudioForward                = GDK_KEY_AudioForward,
    _AudioRepeat                 = GDK_KEY_AudioRepeat,
    _AudioRandomPlay             = GDK_KEY_AudioRandomPlay,
    _Subtitle                    = GDK_KEY_Subtitle,
    _AudioCycleTrack             = GDK_KEY_AudioCycleTrack,
    _CycleAngle                  = GDK_KEY_CycleAngle,
    _FrameBack                   = GDK_KEY_FrameBack,
    _FrameForward                = GDK_KEY_FrameForward,
    _Time                        = GDK_KEY_Time,
    _SelectButton                = GDK_KEY_SelectButton,
    _View                        = GDK_KEY_View,
    _TopMenu                     = GDK_KEY_TopMenu,
    _Red                         = GDK_KEY_Red,
    _Green                       = GDK_KEY_Green,
    _Yellow                      = GDK_KEY_Yellow,
    _Blue                        = GDK_KEY_Blue,
    _Suspend                     = GDK_KEY_Suspend,
    _Hibernate                   = GDK_KEY_Hibernate,
    _TouchpadToggle              = GDK_KEY_TouchpadToggle,
    _Switch_VT_1                 = GDK_KEY_Switch_VT_1,
    _Switch_VT_2                 = GDK_KEY_Switch_VT_2,
    _Switch_VT_3                 = GDK_KEY_Switch_VT_3,
    _Switch_VT_4                 = GDK_KEY_Switch_VT_4,
    _Switch_VT_5                 = GDK_KEY_Switch_VT_5,
    _Switch_VT_6                 = GDK_KEY_Switch_VT_6,
    _Switch_VT_7                 = GDK_KEY_Switch_VT_7,
    _Switch_VT_8                 = GDK_KEY_Switch_VT_8,
    _Switch_VT_9                 = GDK_KEY_Switch_VT_9,
    _Switch_VT_10                = GDK_KEY_Switch_VT_10,
    _Switch_VT_11                = GDK_KEY_Switch_VT_11,
    _Switch_VT_12                = GDK_KEY_Switch_VT_12,
    _Ungrab                      = GDK_KEY_Ungrab,
    _ClearGrab                   = GDK_KEY_ClearGrab,
    _Next_VMode                  = GDK_KEY_Next_VMode,
    _Prev_VMode                  = GDK_KEY_Prev_VMode
    }

-- | Modal keys are: caps lock
isModalKey :: KeyVal -> Bool
isModalKey k
    | k == _Caps_Lock = True
    | otherwise       = False

-- | Modifiers are: shift, control, alt, super, menu
isModifier :: KeyVal -> Bool
isModifier k
    | k == _Shift_L          = True
    | k == _Shift_R          = True
    | k == _Control_L        = True
    | k == _Control_R        = True
    | k == _Alt_L            = True
    | k == _Alt_R            = True
    | k == _Super_L          = True
    | k == _Super_R          = True
    | k == _Menu             = True
    | k == _ISO_Level3_Shift = True
    | otherwise              = False
